<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_addon_registry_core
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of the software this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Architecture';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return '(Core ' . brand_name() . ' code)';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_do',
            'tut_drinking',
            'tut_metadata',
            'tut_sql',
            'tut_url_schemes',
            'tut_seo',
            'tut_selectcode',
            'tut_filtercode',
            'tut_keymap',
            'tut_email',
            'tut_disaster',
            'tut_antispam',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/component.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            '.user.ini',
            'README.md',
            '_config.php',
            'adminzone/.htaccess',
            'adminzone/find_permissions.php',
            'adminzone/index.php',
            'adminzone/pages/comcode/.htaccess',
            'adminzone/pages/comcode/EN/.htaccess',
            'adminzone/pages/comcode/EN/_modsecurity.txt',
            'adminzone/pages/comcode/EN/home.txt',
            'adminzone/pages/comcode/EN/index.html',
            'adminzone/pages/comcode/index.html',
            'adminzone/pages/comcode_custom/.htaccess',
            'adminzone/pages/comcode_custom/EN/.htaccess',
            'adminzone/pages/comcode_custom/EN/index.html',
            'adminzone/pages/comcode_custom/index.html',
            'adminzone/pages/html/.htaccess',
            'adminzone/pages/html/EN/.htaccess',
            'adminzone/pages/html/EN/index.html',
            'adminzone/pages/html/index.html',
            'adminzone/pages/html_custom/EN/.htaccess',
            'adminzone/pages/html_custom/EN/index.html',
            'adminzone/pages/html_custom/index.html',
            'adminzone/pages/index.html',
            'adminzone/pages/minimodules/.htaccess',
            'adminzone/pages/minimodules/index.html',
            'adminzone/pages/minimodules_custom/.htaccess',
            'adminzone/pages/minimodules_custom/index.html',
            'adminzone/pages/modules/.htaccess',
            'adminzone/pages/modules/admin.php',
            'adminzone/pages/modules/admin_email_log.php',
            'adminzone/pages/modules/admin_group_member_timeouts.php',
            'adminzone/pages/modules/admin_version.php',
            'adminzone/pages/modules/index.html',
            'adminzone/pages/modules_custom/.htaccess',
            'adminzone/pages/modules_custom/index.html',
            'caches/.htaccess',
            'caches/http/.htaccess',
            'caches/http/index.html',
            'caches/index.html',
            'caches/lang/.htaccess',
            'caches/lang/EN/.htaccess',
            'caches/lang/EN/index.html',
            'caches/lang/index.html',
            'caches/self_learning/.htaccess',
            'caches/self_learning/index.html',
            'caches/static/.htaccess',
            'caches/static/index.html',
            'cms/index.php',
            'cms/pages/comcode/.htaccess',
            'cms/pages/comcode/EN/.htaccess',
            'cms/pages/comcode/EN/index.html',
            'cms/pages/comcode/index.html',
            'cms/pages/comcode_custom/.htaccess',
            'cms/pages/comcode_custom/EN/.htaccess',
            'cms/pages/comcode_custom/EN/index.html',
            'cms/pages/comcode_custom/index.html',
            'cms/pages/html/.htaccess',
            'cms/pages/html/EN/.htaccess',
            'cms/pages/html/EN/index.html',
            'cms/pages/html/index.html',
            'cms/pages/html_custom/EN/.htaccess',
            'cms/pages/html_custom/EN/index.html',
            'cms/pages/html_custom/index.html',
            'cms/pages/index.html',
            'cms/pages/minimodules/.htaccess',
            'cms/pages/minimodules/index.html',
            'cms/pages/minimodules_custom/.htaccess',
            'cms/pages/minimodules_custom/index.html',
            'cms/pages/modules/.htaccess',
            'cms/pages/modules/cms.php',
            'cms/pages/modules/index.html',
            'cms/pages/modules_custom/.htaccess',
            'cms/pages/modules_custom/index.html',
            'config_editor.php',
            'data/ace/ace.js',
            'data/ace/ace_composr.js',
            'data/ace/ext-beautify.js',
            'data/ace/ext-code_lens.js',
            'data/ace/ext-elastic_tabstops_lite.js',
            'data/ace/ext-emmet.js',
            'data/ace/ext-error_marker.js',
            'data/ace/ext-hardwrap.js',
            'data/ace/ext-keybinding_menu.js',
            'data/ace/ext-language_tools.js',
            'data/ace/ext-linking.js',
            'data/ace/ext-modelist.js',
            'data/ace/ext-options.js',
            'data/ace/ext-prompt.js',
            'data/ace/ext-rtl.js',
            'data/ace/ext-searchbox.js',
            'data/ace/ext-settings_menu.js',
            'data/ace/ext-spellcheck.js',
            'data/ace/ext-split.js',
            'data/ace/ext-static_highlight.js',
            'data/ace/ext-statusbar.js',
            'data/ace/ext-textarea.js',
            'data/ace/ext-themelist.js',
            'data/ace/ext-whitespace.js',
            'data/ace/index.html',
            'data/ace/keybinding-emacs.js',
            'data/ace/keybinding-sublime.js',
            'data/ace/keybinding-vim.js',
            'data/ace/keybinding-vscode.js',
            'data/ace/mode-abap.js',
            'data/ace/mode-abc.js',
            'data/ace/mode-actionscript.js',
            'data/ace/mode-ada.js',
            'data/ace/mode-alda.js',
            'data/ace/mode-apache_conf.js',
            'data/ace/mode-apex.js',
            'data/ace/mode-applescript.js',
            'data/ace/mode-aql.js',
            'data/ace/mode-asciidoc.js',
            'data/ace/mode-asl.js',
            'data/ace/mode-assembly_x86.js',
            'data/ace/mode-autohotkey.js',
            'data/ace/mode-batchfile.js',
            'data/ace/mode-c9search.js',
            'data/ace/mode-c_cpp.js',
            'data/ace/mode-cirru.js',
            'data/ace/mode-clojure.js',
            'data/ace/mode-cobol.js',
            'data/ace/mode-coffee.js',
            'data/ace/mode-coldfusion.js',
            'data/ace/mode-crystal.js',
            'data/ace/mode-csharp.js',
            'data/ace/mode-csound_document.js',
            'data/ace/mode-csound_orchestra.js',
            'data/ace/mode-csound_score.js',
            'data/ace/mode-csp.js',
            'data/ace/mode-css.js',
            'data/ace/mode-curly.js',
            'data/ace/mode-d.js',
            'data/ace/mode-dart.js',
            'data/ace/mode-diff.js',
            'data/ace/mode-django.js',
            'data/ace/mode-dockerfile.js',
            'data/ace/mode-dot.js',
            'data/ace/mode-drools.js',
            'data/ace/mode-edifact.js',
            'data/ace/mode-eiffel.js',
            'data/ace/mode-ejs.js',
            'data/ace/mode-elixir.js',
            'data/ace/mode-elm.js',
            'data/ace/mode-erlang.js',
            'data/ace/mode-forth.js',
            'data/ace/mode-fortran.js',
            'data/ace/mode-fsharp.js',
            'data/ace/mode-fsl.js',
            'data/ace/mode-ftl.js',
            'data/ace/mode-gcode.js',
            'data/ace/mode-gherkin.js',
            'data/ace/mode-gitignore.js',
            'data/ace/mode-glsl.js',
            'data/ace/mode-gobstones.js',
            'data/ace/mode-golang.js',
            'data/ace/mode-graphqlschema.js',
            'data/ace/mode-groovy.js',
            'data/ace/mode-haml.js',
            'data/ace/mode-handlebars.js',
            'data/ace/mode-haskell.js',
            'data/ace/mode-haskell_cabal.js',
            'data/ace/mode-haxe.js',
            'data/ace/mode-hjson.js',
            'data/ace/mode-html.js',
            'data/ace/mode-html_elixir.js',
            'data/ace/mode-html_ruby.js',
            'data/ace/mode-ini.js',
            'data/ace/mode-io.js',
            'data/ace/mode-ion.js',
            'data/ace/mode-jack.js',
            'data/ace/mode-jade.js',
            'data/ace/mode-java.js',
            'data/ace/mode-javascript.js',
            'data/ace/mode-json.js',
            'data/ace/mode-json5.js',
            'data/ace/mode-jsoniq.js',
            'data/ace/mode-jsp.js',
            'data/ace/mode-jssm.js',
            'data/ace/mode-jsx.js',
            'data/ace/mode-julia.js',
            'data/ace/mode-kotlin.js',
            'data/ace/mode-latex.js',
            'data/ace/mode-latte.js',
            'data/ace/mode-less.js',
            'data/ace/mode-liquid.js',
            'data/ace/mode-lisp.js',
            'data/ace/mode-livescript.js',
            'data/ace/mode-logiql.js',
            'data/ace/mode-logtalk.js',
            'data/ace/mode-lsl.js',
            'data/ace/mode-lua.js',
            'data/ace/mode-luapage.js',
            'data/ace/mode-lucene.js',
            'data/ace/mode-makefile.js',
            'data/ace/mode-markdown.js',
            'data/ace/mode-mask.js',
            'data/ace/mode-matlab.js',
            'data/ace/mode-maze.js',
            'data/ace/mode-mediawiki.js',
            'data/ace/mode-mel.js',
            'data/ace/mode-mips.js',
            'data/ace/mode-mixal.js',
            'data/ace/mode-mushcode.js',
            'data/ace/mode-mysql.js',
            'data/ace/mode-nginx.js',
            'data/ace/mode-nim.js',
            'data/ace/mode-nix.js',
            'data/ace/mode-nsis.js',
            'data/ace/mode-nunjucks.js',
            'data/ace/mode-objectivec.js',
            'data/ace/mode-ocaml.js',
            'data/ace/mode-partiql.js',
            'data/ace/mode-pascal.js',
            'data/ace/mode-perl.js',
            'data/ace/mode-pgsql.js',
            'data/ace/mode-php.js',
            'data/ace/mode-php_laravel_blade.js',
            'data/ace/mode-pig.js',
            'data/ace/mode-plain_text.js',
            'data/ace/mode-powershell.js',
            'data/ace/mode-praat.js',
            'data/ace/mode-prisma.js',
            'data/ace/mode-prolog.js',
            'data/ace/mode-properties.js',
            'data/ace/mode-protobuf.js',
            'data/ace/mode-puppet.js',
            'data/ace/mode-python.js',
            'data/ace/mode-qml.js',
            'data/ace/mode-r.js',
            'data/ace/mode-raku.js',
            'data/ace/mode-razor.js',
            'data/ace/mode-rdoc.js',
            'data/ace/mode-red.js',
            'data/ace/mode-redshift.js',
            'data/ace/mode-rhtml.js',
            'data/ace/mode-rst.js',
            'data/ace/mode-ruby.js',
            'data/ace/mode-rust.js',
            'data/ace/mode-sac.js',
            'data/ace/mode-sass.js',
            'data/ace/mode-scad.js',
            'data/ace/mode-scala.js',
            'data/ace/mode-scheme.js',
            'data/ace/mode-scrypt.js',
            'data/ace/mode-scss.js',
            'data/ace/mode-sh.js',
            'data/ace/mode-sjs.js',
            'data/ace/mode-slim.js',
            'data/ace/mode-smarty.js',
            'data/ace/mode-smithy.js',
            'data/ace/mode-snippets.js',
            'data/ace/mode-soy_template.js',
            'data/ace/mode-space.js',
            'data/ace/mode-sparql.js',
            'data/ace/mode-sql.js',
            'data/ace/mode-sqlserver.js',
            'data/ace/mode-stylus.js',
            'data/ace/mode-svg.js',
            'data/ace/mode-swift.js',
            'data/ace/mode-tcl.js',
            'data/ace/mode-terraform.js',
            'data/ace/mode-tex.js',
            'data/ace/mode-text.js',
            'data/ace/mode-textile.js',
            'data/ace/mode-toml.js',
            'data/ace/mode-tsx.js',
            'data/ace/mode-turtle.js',
            'data/ace/mode-twig.js',
            'data/ace/mode-typescript.js',
            'data/ace/mode-vala.js',
            'data/ace/mode-vbscript.js',
            'data/ace/mode-velocity.js',
            'data/ace/mode-verilog.js',
            'data/ace/mode-vhdl.js',
            'data/ace/mode-visualforce.js',
            'data/ace/mode-wollok.js',
            'data/ace/mode-xml.js',
            'data/ace/mode-xquery.js',
            'data/ace/mode-yaml.js',
            'data/ace/mode-zeek.js',
            'data/ace/snippets/abap.js',
            'data/ace/snippets/abc.js',
            'data/ace/snippets/actionscript.js',
            'data/ace/snippets/ada.js',
            'data/ace/snippets/alda.js',
            'data/ace/snippets/apache_conf.js',
            'data/ace/snippets/apex.js',
            'data/ace/snippets/applescript.js',
            'data/ace/snippets/aql.js',
            'data/ace/snippets/asciidoc.js',
            'data/ace/snippets/asl.js',
            'data/ace/snippets/assembly_x86.js',
            'data/ace/snippets/autohotkey.js',
            'data/ace/snippets/batchfile.js',
            'data/ace/snippets/c9search.js',
            'data/ace/snippets/c_cpp.js',
            'data/ace/snippets/cirru.js',
            'data/ace/snippets/clojure.js',
            'data/ace/snippets/cobol.js',
            'data/ace/snippets/coffee.js',
            'data/ace/snippets/coldfusion.js',
            'data/ace/snippets/crystal.js',
            'data/ace/snippets/csharp.js',
            'data/ace/snippets/csound_document.js',
            'data/ace/snippets/csound_orchestra.js',
            'data/ace/snippets/csound_score.js',
            'data/ace/snippets/csp.js',
            'data/ace/snippets/css.js',
            'data/ace/snippets/curly.js',
            'data/ace/snippets/d.js',
            'data/ace/snippets/dart.js',
            'data/ace/snippets/diff.js',
            'data/ace/snippets/django.js',
            'data/ace/snippets/dockerfile.js',
            'data/ace/snippets/dot.js',
            'data/ace/snippets/drools.js',
            'data/ace/snippets/edifact.js',
            'data/ace/snippets/eiffel.js',
            'data/ace/snippets/ejs.js',
            'data/ace/snippets/elixir.js',
            'data/ace/snippets/elm.js',
            'data/ace/snippets/erlang.js',
            'data/ace/snippets/forth.js',
            'data/ace/snippets/fortran.js',
            'data/ace/snippets/fsharp.js',
            'data/ace/snippets/fsl.js',
            'data/ace/snippets/ftl.js',
            'data/ace/snippets/gcode.js',
            'data/ace/snippets/gherkin.js',
            'data/ace/snippets/gitignore.js',
            'data/ace/snippets/glsl.js',
            'data/ace/snippets/gobstones.js',
            'data/ace/snippets/golang.js',
            'data/ace/snippets/graphqlschema.js',
            'data/ace/snippets/groovy.js',
            'data/ace/snippets/haml.js',
            'data/ace/snippets/handlebars.js',
            'data/ace/snippets/haskell.js',
            'data/ace/snippets/haskell_cabal.js',
            'data/ace/snippets/haxe.js',
            'data/ace/snippets/hjson.js',
            'data/ace/snippets/html.js',
            'data/ace/snippets/html_elixir.js',
            'data/ace/snippets/html_ruby.js',
            'data/ace/snippets/index.html',
            'data/ace/snippets/ini.js',
            'data/ace/snippets/io.js',
            'data/ace/snippets/ion.js',
            'data/ace/snippets/jack.js',
            'data/ace/snippets/jade.js',
            'data/ace/snippets/java.js',
            'data/ace/snippets/javascript.js',
            'data/ace/snippets/json.js',
            'data/ace/snippets/json5.js',
            'data/ace/snippets/jsoniq.js',
            'data/ace/snippets/jsp.js',
            'data/ace/snippets/jssm.js',
            'data/ace/snippets/jsx.js',
            'data/ace/snippets/julia.js',
            'data/ace/snippets/kotlin.js',
            'data/ace/snippets/latex.js',
            'data/ace/snippets/latte.js',
            'data/ace/snippets/less.js',
            'data/ace/snippets/liquid.js',
            'data/ace/snippets/lisp.js',
            'data/ace/snippets/livescript.js',
            'data/ace/snippets/logiql.js',
            'data/ace/snippets/logtalk.js',
            'data/ace/snippets/lsl.js',
            'data/ace/snippets/lua.js',
            'data/ace/snippets/luapage.js',
            'data/ace/snippets/lucene.js',
            'data/ace/snippets/makefile.js',
            'data/ace/snippets/markdown.js',
            'data/ace/snippets/mask.js',
            'data/ace/snippets/matlab.js',
            'data/ace/snippets/maze.js',
            'data/ace/snippets/mediawiki.js',
            'data/ace/snippets/mel.js',
            'data/ace/snippets/mips.js',
            'data/ace/snippets/mixal.js',
            'data/ace/snippets/mushcode.js',
            'data/ace/snippets/mysql.js',
            'data/ace/snippets/nginx.js',
            'data/ace/snippets/nim.js',
            'data/ace/snippets/nix.js',
            'data/ace/snippets/nsis.js',
            'data/ace/snippets/nunjucks.js',
            'data/ace/snippets/objectivec.js',
            'data/ace/snippets/ocaml.js',
            'data/ace/snippets/partiql.js',
            'data/ace/snippets/pascal.js',
            'data/ace/snippets/perl.js',
            'data/ace/snippets/pgsql.js',
            'data/ace/snippets/php.js',
            'data/ace/snippets/php_laravel_blade.js',
            'data/ace/snippets/pig.js',
            'data/ace/snippets/plain_text.js',
            'data/ace/snippets/powershell.js',
            'data/ace/snippets/praat.js',
            'data/ace/snippets/prisma.js',
            'data/ace/snippets/prolog.js',
            'data/ace/snippets/properties.js',
            'data/ace/snippets/protobuf.js',
            'data/ace/snippets/puppet.js',
            'data/ace/snippets/python.js',
            'data/ace/snippets/qml.js',
            'data/ace/snippets/r.js',
            'data/ace/snippets/raku.js',
            'data/ace/snippets/razor.js',
            'data/ace/snippets/rdoc.js',
            'data/ace/snippets/red.js',
            'data/ace/snippets/redshift.js',
            'data/ace/snippets/rhtml.js',
            'data/ace/snippets/rst.js',
            'data/ace/snippets/ruby.js',
            'data/ace/snippets/rust.js',
            'data/ace/snippets/sac.js',
            'data/ace/snippets/sass.js',
            'data/ace/snippets/scad.js',
            'data/ace/snippets/scala.js',
            'data/ace/snippets/scheme.js',
            'data/ace/snippets/scrypt.js',
            'data/ace/snippets/scss.js',
            'data/ace/snippets/sh.js',
            'data/ace/snippets/sjs.js',
            'data/ace/snippets/slim.js',
            'data/ace/snippets/smarty.js',
            'data/ace/snippets/smithy.js',
            'data/ace/snippets/snippets.js',
            'data/ace/snippets/soy_template.js',
            'data/ace/snippets/space.js',
            'data/ace/snippets/sparql.js',
            'data/ace/snippets/sql.js',
            'data/ace/snippets/sqlserver.js',
            'data/ace/snippets/stylus.js',
            'data/ace/snippets/svg.js',
            'data/ace/snippets/swift.js',
            'data/ace/snippets/tcl.js',
            'data/ace/snippets/terraform.js',
            'data/ace/snippets/tex.js',
            'data/ace/snippets/text.js',
            'data/ace/snippets/textile.js',
            'data/ace/snippets/toml.js',
            'data/ace/snippets/tsx.js',
            'data/ace/snippets/turtle.js',
            'data/ace/snippets/twig.js',
            'data/ace/snippets/typescript.js',
            'data/ace/snippets/vala.js',
            'data/ace/snippets/vbscript.js',
            'data/ace/snippets/velocity.js',
            'data/ace/snippets/verilog.js',
            'data/ace/snippets/vhdl.js',
            'data/ace/snippets/visualforce.js',
            'data/ace/snippets/wollok.js',
            'data/ace/snippets/xml.js',
            'data/ace/snippets/xquery.js',
            'data/ace/snippets/yaml.js',
            'data/ace/snippets/zeek.js',
            'data/ace/theme-ambiance.js',
            'data/ace/theme-chaos.js',
            'data/ace/theme-chrome.js',
            'data/ace/theme-clouds.js',
            'data/ace/theme-clouds_midnight.js',
            'data/ace/theme-cobalt.js',
            'data/ace/theme-crimson_editor.js',
            'data/ace/theme-dawn.js',
            'data/ace/theme-dracula.js',
            'data/ace/theme-dreamweaver.js',
            'data/ace/theme-eclipse.js',
            'data/ace/theme-github.js',
            'data/ace/theme-gob.js',
            'data/ace/theme-gruvbox.js',
            'data/ace/theme-idle_fingers.js',
            'data/ace/theme-iplastic.js',
            'data/ace/theme-katzenmilch.js',
            'data/ace/theme-kr_theme.js',
            'data/ace/theme-kuroir.js',
            'data/ace/theme-merbivore.js',
            'data/ace/theme-merbivore_soft.js',
            'data/ace/theme-mono_industrial.js',
            'data/ace/theme-monokai.js',
            'data/ace/theme-nord_dark.js',
            'data/ace/theme-one_dark.js',
            'data/ace/theme-pastel_on_dark.js',
            'data/ace/theme-solarized_dark.js',
            'data/ace/theme-solarized_light.js',
            'data/ace/theme-sqlserver.js',
            'data/ace/theme-terminal.js',
            'data/ace/theme-textmate.js',
            'data/ace/theme-tomorrow.js',
            'data/ace/theme-tomorrow_night.js',
            'data/ace/theme-tomorrow_night_blue.js',
            'data/ace/theme-tomorrow_night_bright.js',
            'data/ace/theme-tomorrow_night_eighties.js',
            'data/ace/theme-twilight.js',
            'data/ace/theme-vibrant_ink.js',
            'data/ace/theme-xcode.js',
            'data/ace/worker-base.js',
            'data/ace/worker-coffee.js',
            'data/ace/worker-css.js',
            'data/ace/worker-html.js',
            'data/ace/worker-javascript.js',
            'data/ace/worker-json.js',
            'data/ace/worker-lua.js',
            'data/ace/worker-php.js',
            'data/ace/worker-xml.js',
            'data/ace/worker-xquery.js',
            'data/ajax_tree.php',
            'data/autosave.php',
            'data/confirm_session.php',
            'data/cron_bridge.php',
            'data/cron_bridge.sh',
            'data/csp_logging.php',
            'data/curl-ca-bundle.crt',
            'data/db_meta.bin',
            'data/empty.php',
            'data/endpoint.php',
            'data/external_url_proxy.php',
            'data/files.bin',
            'data/files_previous.bin',
            'data/generate_csrf_token.php',
            'data/geocode.php',
            'data/gravatar.php',
            'data/guids.bin',
            'data/iframe.php',
            'data/images/.htaccess',
            'data/images/index.html',
            'data/incoming_uploads.php',
            'data/index.html',
            'data/installed.php',
            'data/keys/.htaccess',
            'data/keys/index.html',
            'data/keys/telemetry.pub',
            'data/maintenance_status.csv',
            'data/modules/index.html',
            'data/page_link_redirect.php',
            'data/plupload/Moxie.swf',
            'data/plupload/Moxie.xap',
            'data/plupload/index.html',
            'data/polyfills/class_list.js',
            'data/polyfills/dom_init.js',
            'data/polyfills/index.html',
            'data/polyfills/promise.js',
            'data/question_ui.php',
            'data/script.php',
            'data/sheet.php',
            'data/sitemap.php',
            'data/snippet.php',
            'data/soundmanager/index.html',
            'data/soundmanager/soundmanager2.swf',
            'data/soundmanager/soundmanager2_debug.swf',
            'data/soundmanager/soundmanager2_flash9.swf',
            'data/soundmanager/soundmanager2_flash9_debug.swf',
            'data/sounds/index.html',
            'data/sounds/message_background.mp3',
            'data/sounds/message_received.mp3',
            'data/static_cache.php',
            'data/tasks.php',
            'data/unsubscribe.php',
            'data/upload_syndication_auth.php',
            'data/xml_config/.htaccess',
            'data/xml_config/index.html',
            'data_custom/.htaccess',
            'data_custom/errors/.htaccess',
            'data_custom/errors/index.html',
            'data_custom/execute_temp.php',
            'data_custom/execute_temp.php.bundle',
            'data_custom/failed_mail/.htaccess',
            'data_custom/failed_mail/index.html',
            'data_custom/firewall_rules.txt',
            'data_custom/images/.htaccess',
            'data_custom/images/index.html',
            'data_custom/index.html',
            'data_custom/modules/index.html',
            'data_custom/sitemaps/index.html',
            'data_custom/xml_config/.htaccess',
            'data_custom/xml_config/index.html',
            'docs/CODE_OF_CONDUCT.md',
            'docs/CONTRIBUTING.md',
            'docs/INSTALL.md',
            'docs/LICENSE.md',
            'docs/SECURITY.md',
            'docs/SUPPORT.md',
            'docs/THANKS.md',
            'exports/backups/index.html',
            'exports/file_backups/.htaccess',
            'index.php',
            'lang/.htaccess',
            'lang/EN/.htaccess',
            'lang/EN/abstract_file_manager.ini',
            'lang/EN/blocks.ini',
            'lang/EN/critical_error.ini',
            'lang/EN/dates.ini',
            'lang/EN/dearchive.ini',
            'lang/EN/debrand.ini',
            'lang/EN/decision_tree.ini',
            'lang/EN/do_next.ini',
            'lang/EN/email_log.ini',
            'lang/EN/encryption.ini',
            'lang/EN/filtercode.ini',
            'lang/EN/global.ini',
            'lang/EN/group_member_timeouts.ini',
            'lang/EN/index.html',
            'lang/EN/installer.ini',
            'lang/EN/javascript.ini',
            'lang/EN/lang.ini',
            'lang/EN/locations.ini',
            'lang/EN/mail.ini',
            'lang/EN/metadata.ini',
            'lang/EN/permissions.ini',
            'lang/EN/profiling.ini',
            'lang/EN/rss.ini',
            'lang/EN/tasks.ini',
            'lang/EN/upload_syndication.ini',
            'lang/EN/version.ini',
            'lang/EN/zones.ini',
            'lang/index.html',
            'lang/langs.ini',
            'lang/map.ini',
            'lang_custom/.htaccess',
            'lang_custom/EN/.htaccess',
            'lang_custom/EN/index.html',
            'lang_custom/index.html',
            'pages/comcode/.htaccess',
            'pages/comcode/EN/.htaccess',
            'pages/comcode/EN/404.txt',
            'pages/comcode/EN/_rules.txt',
            'pages/comcode/EN/home.txt',
            'pages/comcode/EN/index.html',
            'pages/comcode/EN/keymap.txt',
            'pages/comcode/EN/panel_bottom.txt',
            'pages/comcode/EN/panel_left.txt',
            'pages/comcode/EN/panel_right.txt',
            'pages/comcode/EN/panel_top.txt',
            'pages/comcode/EN/rules.txt',
            'pages/comcode/EN/sitemap.txt',
            'pages/comcode/index.html',
            'pages/comcode_custom/.htaccess',
            'pages/comcode_custom/EN/.htaccess',
            'pages/comcode_custom/EN/index.html',
            'pages/comcode_custom/index.html',
            'pages/html/.htaccess',
            'pages/html/EN/.htaccess',
            'pages/html/EN/index.html',
            'pages/html/index.html',
            'pages/html_custom/EN/.htaccess',
            'pages/html_custom/EN/index.html',
            'pages/html_custom/index.html',
            'pages/index.html',
            'pages/minimodules/.htaccess',
            'pages/minimodules/index.html',
            'pages/minimodules_custom/.htaccess',
            'pages/minimodules_custom/index.html',
            'pages/modules/.htaccess',
            'pages/modules/forums.php',
            'pages/modules/index.html',
            'pages/modules/login.php',
            'pages/modules_custom/.htaccess',
            'pages/modules_custom/index.html',
            'site/index.php',
            'site/pages/comcode/.htaccess',
            'site/pages/comcode/EN/.htaccess',
            'site/pages/comcode/EN/home.txt',
            'site/pages/comcode/EN/index.html',
            'site/pages/comcode/EN/panel_left.txt',
            'site/pages/comcode/EN/panel_right.txt',
            'site/pages/comcode/EN/userguide_comcode.txt',
            'site/pages/comcode/index.html',
            'site/pages/comcode_custom/.htaccess',
            'site/pages/comcode_custom/EN/.htaccess',
            'site/pages/comcode_custom/EN/index.html',
            'site/pages/comcode_custom/index.html',
            'site/pages/html/.htaccess',
            'site/pages/html/EN/.htaccess',
            'site/pages/html/EN/index.html',
            'site/pages/html/index.html',
            'site/pages/html_custom/EN/.htaccess',
            'site/pages/html_custom/EN/index.html',
            'site/pages/html_custom/index.html',
            'site/pages/index.html',
            'site/pages/minimodules/.htaccess',
            'site/pages/minimodules/index.html',
            'site/pages/minimodules_custom/.htaccess',
            'site/pages/minimodules_custom/index.html',
            'site/pages/modules/.htaccess',
            'site/pages/modules/index.html',
            'site/pages/modules_custom/.htaccess',
            'site/pages/modules_custom/index.html',
            'sources/.htaccess',
            'sources/abstract_file_manager.php',
            'sources/ajax.php',
            'sources/anti_leech.php',
            'sources/antispam.php',
            'sources/autosave.php',
            'sources/block_add.php',
            'sources/blocks.php',
            'sources/blocks/.htaccess',
            'sources/blocks/index.html',
            'sources/blocks/main_content.php',
            'sources/blocks/main_content_filtering.php',
            'sources/blocks/main_db_notes.php',
            'sources/blocks/main_greeting.php',
            'sources/blocks/main_include_module.php',
            'sources/blocks/main_multi_content.php',
            'sources/blocks/main_notes.php',
            'sources/blocks/side_personal_stats.php',
            'sources/blocks/top_login.php',
            'sources/blocks/top_personal_stats.php',
            'sources/caches.php',
            'sources/caches2.php',
            'sources/caches3.php',
            'sources/character_sets.php',
            'sources/config.php',
            'sources/config2.php',
            'sources/content.php',
            'sources/content2.php',
            'sources/cpf_install.php',
            'sources/critical_errors.php',
            'sources/cron.php',
            'sources/crud_module.php',
            'sources/crypt.php',
            'sources/crypt_maintenance.php',
            'sources/csp.php',
            'sources/csrf_filter.php',
            'sources/database.php',
            'sources/database_helper.php',
            'sources/database_relations.php',
            'sources/database_repair.php',
            'sources/database_search.php',
            'sources/database_security_filter.php',
            'sources/debug_fs.php',
            'sources/decision_tree.php',
            'sources/deep_clean.php',
            'sources/developer_tools.php',
            'sources/diff.php',
            'sources/diff/.htaccess',
            'sources/diff/Diff.php',
            'sources/diff/Diff/.htaccess',
            'sources/diff/Diff/Engine/.htaccess',
            'sources/diff/Diff/Engine/index.html',
            'sources/diff/Diff/Engine/native.php',
            'sources/diff/Diff/Engine/shell.php',
            'sources/diff/Diff/Engine/string.php',
            'sources/diff/Diff/Engine/xdiff.php',
            'sources/diff/Diff/Mapped.php',
            'sources/diff/Diff/Renderer.php',
            'sources/diff/Diff/Renderer/.htaccess',
            'sources/diff/Diff/Renderer/context.php',
            'sources/diff/Diff/Renderer/index.html',
            'sources/diff/Diff/Renderer/inline.php',
            'sources/diff/Diff/Renderer/unified.php',
            'sources/diff/Diff/ThreeWay.php',
            'sources/diff/Diff/index.html',
            'sources/diff/Diff3.php',
            'sources/diff/index.html',
            'sources/encryption.php',
            'sources/endpoints.php',
            'sources/exif.php',
            'sources/failure.php',
            'sources/failure_spammers.php',
            'sources/file_permissions_check.php',
            'sources/files.php',
            'sources/files2.php',
            'sources/files_spreadsheets_read.php',
            'sources/files_spreadsheets_write.php',
            'sources/filtercode.php',
            'sources/firephp.php',
            'sources/forum_stub.php',
            'sources/global.php',
            'sources/global2.php',
            'sources/global3.php',
            'sources/global4.php',
            'sources/group_member_timeouts.php',
            'sources/hooks/.htaccess',
            'sources/hooks/blocks/.htaccess',
            'sources/hooks/blocks/index.html',
            'sources/hooks/blocks/main_notes/.htaccess',
            'sources/hooks/blocks/main_notes/index.html',
            'sources/hooks/blocks/main_staff_checklist/version.php',
            'sources/hooks/endpoints/.htaccess',
            'sources/hooks/endpoints/account/.htaccess',
            'sources/hooks/endpoints/account/index.html',
            'sources/hooks/endpoints/content/.htaccess',
            'sources/hooks/endpoints/content/index.html',
            'sources/hooks/endpoints/index.html',
            'sources/hooks/endpoints/misc/.htaccess',
            'sources/hooks/endpoints/misc/index.html',
            'sources/hooks/form_handlers/.htaccess',
            'sources/hooks/form_handlers/catalogue_entry/.htaccess',
            'sources/hooks/form_handlers/catalogue_entry/index.html',
            'sources/hooks/form_handlers/index.html',
            'sources/hooks/form_handlers/join/.htaccess',
            'sources/hooks/form_handlers/join/index.html',
            'sources/hooks/form_handlers/profile_edit/.htaccess',
            'sources/hooks/form_handlers/profile_edit/index.html',
            'sources/hooks/index.html',
            'sources/hooks/modules/.htaccess',
            'sources/hooks/modules/index.html',
            'sources/hooks/modules/video_syndication/.htaccess',
            'sources/hooks/modules/video_syndication/index.html',
            'sources/hooks/systems/.htaccess',
            'sources/hooks/systems/actionlog/.htaccess',
            'sources/hooks/systems/actionlog/core.php',
            'sources/hooks/systems/actionlog/index.html',
            'sources/hooks/systems/addon_registry/.htaccess',
            'sources/hooks/systems/addon_registry/core.php',
            'sources/hooks/systems/addon_registry/index.html',
            'sources/hooks/systems/ajax_tree/.htaccess',
            'sources/hooks/systems/ajax_tree/index.html',
            'sources/hooks/systems/block_ui_renderers/.htaccess',
            'sources/hooks/systems/block_ui_renderers/core.php',
            'sources/hooks/systems/block_ui_renderers/index.html',
            'sources/hooks/systems/cdn_transfer/.htaccess',
            'sources/hooks/systems/cdn_transfer/index.html',
            'sources/hooks/systems/chmod/.htaccess',
            'sources/hooks/systems/chmod/index.html',
            'sources/hooks/systems/cns_auth/.htaccess',
            'sources/hooks/systems/cns_cpf_filter/options.php',
            'sources/hooks/systems/cns_implicit_usergroups/.htaccess',
            'sources/hooks/systems/cns_implicit_usergroups/index.html',
            'sources/hooks/systems/commandr_fs_extended_member/group_timeouts.php',
            'sources/hooks/systems/contact_forms/.htaccess',
            'sources/hooks/systems/contact_forms/index.html',
            'sources/hooks/systems/content_meta_aware/.htaccess',
            'sources/hooks/systems/content_meta_aware/index.html',
            'sources/hooks/systems/contentious_overrides/.htaccess',
            'sources/hooks/systems/contentious_overrides/index.html',
            'sources/hooks/systems/cron/.htaccess',
            'sources/hooks/systems/cron/block_caching.php',
            'sources/hooks/systems/cron/cache_cleanup.php',
            'sources/hooks/systems/cron/decache_events.php',
            'sources/hooks/systems/cron/dynamic_firewall.php',
            'sources/hooks/systems/cron/git_autopull.php',
            'sources/hooks/systems/cron/group_member_timeouts.php',
            'sources/hooks/systems/cron/implicit_usergroup_sync.php',
            'sources/hooks/systems/cron/index.html',
            'sources/hooks/systems/cron/mail_queue.php',
            'sources/hooks/systems/cron/missing_editfrom.php',
            'sources/hooks/systems/cron/sitemap.php',
            'sources/hooks/systems/cron/tasks.php',
            'sources/hooks/systems/directives/.htaccess',
            'sources/hooks/systems/directives/index.html',
            'sources/hooks/systems/disposable_values/.htaccess',
            'sources/hooks/systems/disposable_values/index.html',
            'sources/hooks/systems/disposable_values/page_views.php',
            'sources/hooks/systems/geocoding/.htaccess',
            'sources/hooks/systems/geocoding/bing.php',
            'sources/hooks/systems/geocoding/google.php',
            'sources/hooks/systems/geocoding/index.html',
            'sources/hooks/systems/geocoding/mapquest.php',
            'sources/hooks/systems/index.html',
            'sources/hooks/systems/login_providers/.htaccess',
            'sources/hooks/systems/login_providers/httpauth.php',
            'sources/hooks/systems/login_providers/index.html',
            'sources/hooks/systems/login_providers_direct_auth/.htaccess',
            'sources/hooks/systems/login_providers_direct_auth/index.html',
            'sources/hooks/systems/non_active_urls/.htaccess',
            'sources/hooks/systems/non_active_urls/index.html',
            'sources/hooks/systems/notifications/core_staff.php',
            'sources/hooks/systems/notifications/error_occurred.php',
            'sources/hooks/systems/notifications/task_completed.php',
            'sources/hooks/systems/page_groupings/.htaccess',
            'sources/hooks/systems/page_groupings/core.php',
            'sources/hooks/systems/page_groupings/index.html',
            'sources/hooks/systems/preview/.htaccess',
            'sources/hooks/systems/preview/block_comcode.php',
            'sources/hooks/systems/preview/index.html',
            'sources/hooks/systems/resource_meta_aware/.htaccess',
            'sources/hooks/systems/resource_meta_aware/index.html',
            'sources/hooks/systems/resource_meta_aware/mail.php',
            'sources/hooks/systems/site_html_pages/.htaccess',
            'sources/hooks/systems/site_html_pages/index.html',
            'sources/hooks/systems/sitemap/.htaccess',
            'sources/hooks/systems/sitemap/entry_point.php',
            'sources/hooks/systems/sitemap/index.html',
            'sources/hooks/systems/sitemap/page.php',
            'sources/hooks/systems/sitemap/page_grouping.php',
            'sources/hooks/systems/sitemap/root.php',
            'sources/hooks/systems/sitemap/zone.php',
            'sources/hooks/systems/sitemap_ping/.htaccess',
            'sources/hooks/systems/sitemap_ping/index.html',
            'sources/hooks/systems/snippets/.htaccess',
            'sources/hooks/systems/snippets/background_template_compilation.php',
            'sources/hooks/systems/snippets/block.php',
            'sources/hooks/systems/snippets/css_compile__text.php',
            'sources/hooks/systems/snippets/index.html',
            'sources/hooks/systems/spam_heuristics/.htaccess',
            'sources/hooks/systems/spam_heuristics/alien_code.php',
            'sources/hooks/systems/spam_heuristics/autonomous.php',
            'sources/hooks/systems/spam_heuristics/country.php',
            'sources/hooks/systems/spam_heuristics/frequency.php',
            'sources/hooks/systems/spam_heuristics/guest.php',
            'sources/hooks/systems/spam_heuristics/header_absence.php',
            'sources/hooks/systems/spam_heuristics/index.html',
            'sources/hooks/systems/spam_heuristics/join_closeness.php',
            'sources/hooks/systems/spam_heuristics/keywords.php',
            'sources/hooks/systems/spam_heuristics/links.php',
            'sources/hooks/systems/spam_heuristics/missing_js.php',
            'sources/hooks/systems/spam_heuristics/pasting.php',
            'sources/hooks/systems/spam_heuristics/posting_speed.php',
            'sources/hooks/systems/spam_heuristics/repetition.php',
            'sources/hooks/systems/spam_heuristics/user_agents.php',
            'sources/hooks/systems/startup/.htaccess',
            'sources/hooks/systems/startup/index.html',
            'sources/hooks/systems/symbols/.htaccess',
            'sources/hooks/systems/symbols/BETA_CSS_PROPERTY.php',
            'sources/hooks/systems/symbols/CONTENT_COUNT.php',
            'sources/hooks/systems/symbols/COUNTRY.php',
            'sources/hooks/systems/symbols/COUNTRY_CODE_TO_NAME.php',
            'sources/hooks/systems/symbols/COUNTRY_NAME_TO_CODE.php',
            'sources/hooks/systems/symbols/DEEP_CLEAN.php',
            'sources/hooks/systems/symbols/FILE_EXISTS.php',
            'sources/hooks/systems/symbols/REGION.php',
            'sources/hooks/systems/symbols/SYMBOL_DATA_AS_JSON.php',
            'sources/hooks/systems/symbols/index.html',
            'sources/hooks/systems/syndication/.htaccess',
            'sources/hooks/systems/syndication/index.html',
            'sources/hooks/systems/tasks/.htaccess',
            'sources/hooks/systems/tasks/create_index.php',
            'sources/hooks/systems/tasks/index.html',
            'sources/hooks/systems/tasks/meta_tree_rebuild.php',
            'sources/hooks/systems/tasks/sitemap.php',
            'sources/hooks/systems/trusted_sites/.htaccess',
            'sources/hooks/systems/trusted_sites/core.php',
            'sources/hooks/systems/trusted_sites/index.html',
            'sources/hooks/systems/upload_syndication/.htaccess',
            'sources/hooks/systems/upload_syndication/index.html',
            'sources/hooks/systems/upon_access_denied/.htaccess',
            'sources/hooks/systems/upon_access_denied/index.html',
            'sources/hooks/systems/upon_action_logging/.htaccess',
            'sources/hooks/systems/upon_action_logging/index.html',
            'sources/hooks/systems/upon_login/.htaccess',
            'sources/hooks/systems/upon_login/index.html',
            'sources/hooks/systems/upon_page_load/.htaccess',
            'sources/hooks/systems/upon_page_load/index.html',
            'sources/hooks/systems/upon_query/.htaccess',
            'sources/hooks/systems/upon_query/index.html',
            'sources/http.php',
            'sources/images.php',
            'sources/images2.php',
            'sources/images_cleanup_pipeline.php',
            'sources/incoming_uploads.php',
            'sources/index.html',
            'sources/input_filter.php',
            'sources/input_filter_2.php',
            'sources/integrator.php',
            'sources/jsmin.php',
            'sources/lang.php',
            'sources/lang2.php',
            'sources/lang3.php',
            'sources/lang_compile.php',
            'sources/lang_filter_EN.php',
            'sources/lang_stemmer_EN.php',
            'sources/locations.php',
            'sources/locations_cpfs.php',
            'sources/locations_geocoding.php',
            'sources/mail.php',
            'sources/mail2.php',
            'sources/mail_dkim.php',
            'sources/mail_forms.php',
            'sources/mail_integration.php',
            'sources/mime_types.php',
            'sources/miniblocks/.htaccess',
            'sources/miniblocks/index.html',
            'sources/minikernel.php',
            'sources/misc_scripts.php',
            'sources/output_compression.php',
            'sources/override_api.php',
            'sources/permissions.php',
            'sources/permissions2.php',
            'sources/permissions3.php',
            'sources/persistent_caching/.htaccess',
            'sources/persistent_caching/apc.php',
            'sources/persistent_caching/apcu.php',
            'sources/persistent_caching/filesystem.php',
            'sources/persistent_caching/index.html',
            'sources/persistent_caching/memcache.php',
            'sources/persistent_caching/memcached.php',
            'sources/persistent_caching/wincache.php',
            'sources/persistent_caching/xcache.php',
            'sources/profiler.php',
            'sources/rss.php',
            'sources/selectcode.php',
            'sources/shared_installs.php',
            'sources/site.php',
            'sources/site2.php',
            'sources/site_adminzone.php',
            'sources/site_html_pages.php',
            'sources/sitemap.php',
            'sources/sitemap_ajax.php',
            'sources/sitemap_xml.php',
            'sources/static_cache.php',
            'sources/submit.php',
            'sources/symbols.php',
            'sources/symbols2.php',
            'sources/syndication.php',
            'sources/tar.php',
            'sources/tar2.php',
            'sources/tasks.php',
            'sources/tempcode.php',
            'sources/tempcode_compiler.php',
            'sources/tempcode_optimiser.php',
            'sources/templates.php',
            'sources/temporal.php',
            'sources/temporal2.php',
            'sources/textfiles.php',
            'sources/themes.php',
            'sources/type_sanitisation.php',
            'sources/upload_syndication.php',
            'sources/uploads.php',
            'sources/uploads2.php',
            'sources/url_remappings.php',
            'sources/urls.php',
            'sources/urls2.php',
            'sources/urls_simplifier.php',
            'sources/users.php',
            'sources/users2.php',
            'sources/users_active_actions.php',
            'sources/users_inactive_occasionals.php',
            'sources/version.php',
            'sources/version2.php',
            'sources/view_modes.php',
            'sources/web_resources.php',
            'sources/web_resources2.php',
            'sources/wordfilter.php',
            'sources/xhtml.php',
            'sources/xml.php',
            'sources/xmlrpc.php',
            'sources/zip.php',
            'sources/zones.php',
            'sources/zones2.php',
            'sources/zones3.php',
            'sources_custom/.htaccess',
            'sources_custom/blocks/.htaccess',
            'sources_custom/blocks/index.html',
            'sources_custom/database/.htaccess',
            'sources_custom/database/index.html',
            'sources_custom/hooks/.htaccess',
            'sources_custom/hooks/blocks/.htaccess',
            'sources_custom/hooks/blocks/index.html',
            'sources_custom/hooks/blocks/main_notes/.htaccess',
            'sources_custom/hooks/blocks/main_notes/index.html',
            'sources_custom/hooks/endpoints/.htaccess',
            'sources_custom/hooks/endpoints/account/.htaccess',
            'sources_custom/hooks/endpoints/account/index.html',
            'sources_custom/hooks/endpoints/content/.htaccess',
            'sources_custom/hooks/endpoints/content/index.html',
            'sources_custom/hooks/endpoints/index.html',
            'sources_custom/hooks/endpoints/misc/.htaccess',
            'sources_custom/hooks/endpoints/misc/index.html',
            'sources_custom/hooks/form_handlers/.htaccess',
            'sources_custom/hooks/form_handlers/catalogue_entry/.htaccess',
            'sources_custom/hooks/form_handlers/catalogue_entry/index.html',
            'sources_custom/hooks/form_handlers/index.html',
            'sources_custom/hooks/form_handlers/join/.htaccess',
            'sources_custom/hooks/form_handlers/join/index.html',
            'sources_custom/hooks/form_handlers/profile_edit/.htaccess',
            'sources_custom/hooks/form_handlers/profile_edit/index.html',
            'sources_custom/hooks/index.html',
            'sources_custom/hooks/modules/.htaccess',
            'sources_custom/hooks/modules/index.html',
            'sources_custom/hooks/modules/video_syndication/.htaccess',
            'sources_custom/hooks/modules/video_syndication/index.html',
            'sources_custom/hooks/systems/.htaccess',
            'sources_custom/hooks/systems/actionlog/.htaccess',
            'sources_custom/hooks/systems/actionlog/index.html',
            'sources_custom/hooks/systems/addon_registry/.htaccess',
            'sources_custom/hooks/systems/addon_registry/index.html',
            'sources_custom/hooks/systems/ajax_tree/.htaccess',
            'sources_custom/hooks/systems/ajax_tree/index.html',
            'sources_custom/hooks/systems/block_ui_renderers/.htaccess',
            'sources_custom/hooks/systems/block_ui_renderers/index.html',
            'sources_custom/hooks/systems/cdn_transfer/.htaccess',
            'sources_custom/hooks/systems/cdn_transfer/index.html',
            'sources_custom/hooks/systems/chmod/.htaccess',
            'sources_custom/hooks/systems/chmod/index.html',
            'sources_custom/hooks/systems/cns_auth/.htaccess',
            'sources_custom/hooks/systems/cns_implicit_usergroups/.htaccess',
            'sources_custom/hooks/systems/cns_implicit_usergroups/index.html',
            'sources_custom/hooks/systems/contact_forms/.htaccess',
            'sources_custom/hooks/systems/contact_forms/index.html',
            'sources_custom/hooks/systems/content_meta_aware/.htaccess',
            'sources_custom/hooks/systems/content_meta_aware/index.html',
            'sources_custom/hooks/systems/contentious_overrides/.htaccess',
            'sources_custom/hooks/systems/contentious_overrides/index.html',
            'sources_custom/hooks/systems/cron/.htaccess',
            'sources_custom/hooks/systems/cron/index.html',
            'sources_custom/hooks/systems/directives/.htaccess',
            'sources_custom/hooks/systems/directives/index.html',
            'sources_custom/hooks/systems/disposable_values/.htaccess',
            'sources_custom/hooks/systems/disposable_values/index.html',
            'sources_custom/hooks/systems/index.html',
            'sources_custom/hooks/systems/login_providers/.htaccess',
            'sources_custom/hooks/systems/login_providers/index.html',
            'sources_custom/hooks/systems/login_providers_direct_auth/.htaccess',
            'sources_custom/hooks/systems/login_providers_direct_auth/index.html',
            'sources_custom/hooks/systems/non_active_urls/.htaccess',
            'sources_custom/hooks/systems/non_active_urls/index.html',
            'sources_custom/hooks/systems/page_groupings/.htaccess',
            'sources_custom/hooks/systems/page_groupings/index.html',
            'sources_custom/hooks/systems/preview/.htaccess',
            'sources_custom/hooks/systems/preview/index.html',
            'sources_custom/hooks/systems/resource_meta_aware/.htaccess',
            'sources_custom/hooks/systems/resource_meta_aware/index.html',
            'sources_custom/hooks/systems/sitemap/.htaccess',
            'sources_custom/hooks/systems/sitemap/index.html',
            'sources_custom/hooks/systems/sitemap_ping/.htaccess',
            'sources_custom/hooks/systems/sitemap_ping/index.html',
            'sources_custom/hooks/systems/snippets/.htaccess',
            'sources_custom/hooks/systems/snippets/index.html',
            'sources_custom/hooks/systems/spam_heuristics/.htaccess',
            'sources_custom/hooks/systems/spam_heuristics/index.html',
            'sources_custom/hooks/systems/startup/.htaccess',
            'sources_custom/hooks/systems/startup/index.html',
            'sources_custom/hooks/systems/symbols/.htaccess',
            'sources_custom/hooks/systems/symbols/index.html',
            'sources_custom/hooks/systems/syndication/.htaccess',
            'sources_custom/hooks/systems/syndication/index.html',
            'sources_custom/hooks/systems/tasks/.htaccess',
            'sources_custom/hooks/systems/tasks/index.html',
            'sources_custom/hooks/systems/trusted_sites/.htaccess',
            'sources_custom/hooks/systems/trusted_sites/index.html',
            'sources_custom/hooks/systems/upload_syndication/.htaccess',
            'sources_custom/hooks/systems/upload_syndication/index.html',
            'sources_custom/hooks/systems/upon_access_denied/.htaccess',
            'sources_custom/hooks/systems/upon_access_denied/index.html',
            'sources_custom/hooks/systems/upon_action_logging/.htaccess',
            'sources_custom/hooks/systems/upon_action_logging/index.html',
            'sources_custom/hooks/systems/upon_login/.htaccess',
            'sources_custom/hooks/systems/upon_login/index.html',
            'sources_custom/hooks/systems/upon_page_load/.htaccess',
            'sources_custom/hooks/systems/upon_page_load/index.html',
            'sources_custom/hooks/systems/upon_query/.htaccess',
            'sources_custom/hooks/systems/upon_query/index.html',
            'sources_custom/index.html',
            'sources_custom/miniblocks/.htaccess',
            'sources_custom/miniblocks/index.html',
            'temp/.htaccess',
            'temp/index.html',
            'text/.htaccess',
            'text/EN/.htaccess',
            'text/EN/index.html',
            'text/EN/synonyms.txt',
            'text/EN/too_common_words.txt',
            'text/EN/word_characters.txt',
            'text/bots.txt',
            'text/index.html',
            'text/unbannable_dns.txt',
            'text/unbannable_ips.txt',
            'text/uptime_bots.txt',
            'text_custom/.htaccess',
            'text_custom/EN/.htaccess',
            'text_custom/EN/index.html',
            'text_custom/index.html',
            'themes/admin/css/.htaccess',
            'themes/admin/css/adminzone.css',
            'themes/admin/css/index.html',
            'themes/admin/css_custom/.htaccess',
            'themes/admin/css_custom/index.html',
            'themes/admin/images/.htaccess',
            'themes/admin/images/index.html',
            'themes/admin/images_custom/.htaccess',
            'themes/admin/images_custom/index.html',
            'themes/admin/index.html',
            'themes/admin/javascript/.htaccess',
            'themes/admin/javascript/admin.js',
            'themes/admin/javascript/index.html',
            'themes/admin/javascript_custom/.htaccess',
            'themes/admin/javascript_custom/index.html',
            'themes/admin/templates/.htaccess',
            'themes/admin/templates/ADMIN_ZONE_SEARCH.tpl',
            'themes/admin/templates/GLOBAL_HTML_WRAP.tpl',
            'themes/admin/templates/index.html',
            'themes/admin/templates_cached/.htaccess',
            'themes/admin/templates_cached/EN/index.html',
            'themes/admin/templates_cached/index.html',
            'themes/admin/templates_custom/.htaccess',
            'themes/admin/templates_custom/index.html',
            'themes/admin/text/.htaccess',
            'themes/admin/text/index.html',
            'themes/admin/text_custom/.htaccess',
            'themes/admin/text_custom/index.html',
            'themes/admin/theme.ini',
            'themes/admin/xml/.htaccess',
            'themes/admin/xml/index.html',
            'themes/admin/xml_custom/.htaccess',
            'themes/admin/xml_custom/index.html',
            'themes/default/css/.htaccess',
            'themes/default/css/_base.css',
            'themes/default/css/_colours.css',
            'themes/default/css/_install_colours.css',
            'themes/default/css/adminzone.css',
            'themes/default/css/carousels.css',
            'themes/default/css/email.css',
            'themes/default/css/global.css',
            'themes/default/css/index.html',
            'themes/default/css/install.css',
            'themes/default/css/login.css',
            'themes/default/css/modern_tabs.css',
            'themes/default/css/no_cache.css',
            'themes/default/css/personal_stats.css',
            'themes/default/css/sitemap_editor.css',
            'themes/default/css/skitter.css',
            'themes/default/css/toastify.css',
            'themes/default/css/widget_plupload.css',
            'themes/default/css_custom/.htaccess',
            'themes/default/css_custom/index.html',
            'themes/default/images/.htaccess',
            'themes/default/images/EN/index.html',
            'themes/default/images/EN/logo/-logo.png',
            'themes/default/images/EN/logo/index.html',
            'themes/default/images/EN/logo/small_logo.png',
            'themes/default/images/EN/logo/small_white_logo.png',
            'themes/default/images/EN/logo/standalone_logo.png',
            'themes/default/images/arrow_ruler.svg',
            'themes/default/images/backgrounds/background_image.svg',
            'themes/default/images/backgrounds/block_background.svg',
            'themes/default/images/backgrounds/index.html',
            'themes/default/images/backgrounds/inner_background.svg',
            'themes/default/images/backgrounds/outer_background.svg',
            'themes/default/images/blank.gif',
            'themes/default/images/edited.svg',
            'themes/default/images/favicon.ico',
            'themes/default/images/help_jumpout.svg',
            'themes/default/images/icons/admin/add.svg',
            'themes/default/images/icons/admin/add_one_category.svg',
            'themes/default/images/icons/admin/add_to_category.svg',
            'themes/default/images/icons/admin/back.svg',
            'themes/default/images/icons/admin/delete.svg',
            'themes/default/images/icons/admin/delete2.svg',
            'themes/default/images/icons/admin/delete3.svg',
            'themes/default/images/icons/admin/edit.svg',
            'themes/default/images/icons/admin/edit2.svg',
            'themes/default/images/icons/admin/edit_one_category.svg',
            'themes/default/images/icons/admin/edit_this.svg',
            'themes/default/images/icons/admin/edit_this_category.svg',
            'themes/default/images/icons/admin/export.svg',
            'themes/default/images/icons/admin/export_spreadsheet.svg',
            'themes/default/images/icons/admin/import.svg',
            'themes/default/images/icons/admin/import_spreadsheet.svg',
            'themes/default/images/icons/admin/index.html',
            'themes/default/images/icons/admin/merge.svg',
            'themes/default/images/icons/admin/move.svg',
            'themes/default/images/icons/admin/remove.svg',
            'themes/default/images/icons/admin/sync.svg',
            'themes/default/images/icons/admin/tool.svg',
            'themes/default/images/icons/admin/tools.svg',
            'themes/default/images/icons/admin/view_archive.svg',
            'themes/default/images/icons/admin/view_this.svg',
            'themes/default/images/icons/admin/view_this_category.svg',
            'themes/default/images/icons/admin/xml.svg',
            'themes/default/images/icons/arrow_box/arrow_box.svg',
            'themes/default/images/icons/arrow_box/arrow_box_hover.svg',
            'themes/default/images/icons/arrow_box/index.html',
            'themes/default/images/icons/breadcrumbs.svg',
            'themes/default/images/icons/buttons/advanced.svg',
            'themes/default/images/icons/buttons/all.svg',
            'themes/default/images/icons/buttons/all2.svg',
            'themes/default/images/icons/buttons/back.svg',
            'themes/default/images/icons/buttons/calculate.svg',
            'themes/default/images/icons/buttons/cancel.svg',
            'themes/default/images/icons/buttons/cancel2.svg',
            'themes/default/images/icons/buttons/choose.svg',
            'themes/default/images/icons/buttons/clear.svg',
            'themes/default/images/icons/buttons/close.svg',
            'themes/default/images/icons/buttons/closed.svg',
            'themes/default/images/icons/buttons/convert.svg',
            'themes/default/images/icons/buttons/copy.svg',
            'themes/default/images/icons/buttons/download.svg',
            'themes/default/images/icons/buttons/filter.svg',
            'themes/default/images/icons/buttons/full_size.svg',
            'themes/default/images/icons/buttons/index.html',
            'themes/default/images/icons/buttons/more.svg',
            'themes/default/images/icons/buttons/new_comment.svg',
            'themes/default/images/icons/buttons/new_post_full.svg',
            'themes/default/images/icons/buttons/new_reply.svg',
            'themes/default/images/icons/buttons/next.svg',
            'themes/default/images/icons/buttons/next_none.svg',
            'themes/default/images/icons/buttons/no.svg',
            'themes/default/images/icons/buttons/pause.svg',
            'themes/default/images/icons/buttons/preview.svg',
            'themes/default/images/icons/buttons/previous.svg',
            'themes/default/images/icons/buttons/previous_none.svg',
            'themes/default/images/icons/buttons/proceed.svg',
            'themes/default/images/icons/buttons/proceed2.svg',
            'themes/default/images/icons/buttons/redirect.svg',
            'themes/default/images/icons/buttons/report.svg',
            'themes/default/images/icons/buttons/save.svg',
            'themes/default/images/icons/buttons/search.svg',
            'themes/default/images/icons/buttons/send.svg',
            'themes/default/images/icons/buttons/settings.svg',
            'themes/default/images/icons/buttons/shrink_size.svg',
            'themes/default/images/icons/buttons/simple.svg',
            'themes/default/images/icons/buttons/skip.svg',
            'themes/default/images/icons/buttons/sort.svg',
            'themes/default/images/icons/buttons/thumbnail.svg',
            'themes/default/images/icons/buttons/undo.svg',
            'themes/default/images/icons/buttons/upload.svg',
            'themes/default/images/icons/buttons/yes.svg',
            'themes/default/images/icons/content_types/audio.svg',
            'themes/default/images/icons/content_types/image.svg',
            'themes/default/images/icons/content_types/index.html',
            'themes/default/images/icons/content_types/member.svg',
            'themes/default/images/icons/content_types/multimedia.svg',
            'themes/default/images/icons/content_types/page.svg',
            'themes/default/images/icons/content_types/post.svg',
            'themes/default/images/icons/content_types/topic.svg',
            'themes/default/images/icons/content_types/video.svg',
            'themes/default/images/icons/editor/comcode.svg',
            'themes/default/images/icons/features.svg',
            'themes/default/images/icons/feedback/index.html',
            'themes/default/images/icons/feedback/rating.svg',
            'themes/default/images/icons/file_types/email_link.svg',
            'themes/default/images/icons/file_types/external_link.svg',
            'themes/default/images/icons/file_types/index.html',
            'themes/default/images/icons/file_types/page_archive.svg',
            'themes/default/images/icons/file_types/page_css.svg',
            'themes/default/images/icons/file_types/page_doc.svg',
            'themes/default/images/icons/file_types/page_feed.svg',
            'themes/default/images/icons/file_types/page_js.svg',
            'themes/default/images/icons/file_types/page_media.svg',
            'themes/default/images/icons/file_types/page_odp.svg',
            'themes/default/images/icons/file_types/page_ods.svg',
            'themes/default/images/icons/file_types/page_odt.svg',
            'themes/default/images/icons/file_types/page_pdf.svg',
            'themes/default/images/icons/file_types/page_ppt.svg',
            'themes/default/images/icons/file_types/page_torrent.svg',
            'themes/default/images/icons/file_types/page_tpl.svg',
            'themes/default/images/icons/file_types/page_txt.svg',
            'themes/default/images/icons/file_types/page_xls.svg',
            'themes/default/images/icons/file_types/page_xml.svg',
            'themes/default/images/icons/help.svg',
            'themes/default/images/icons/helper_panel/hide.svg',
            'themes/default/images/icons/helper_panel/index.html',
            'themes/default/images/icons/helper_panel/show.svg',
            'themes/default/images/icons/index.html',
            'themes/default/images/icons/links/amazon.svg',
            'themes/default/images/icons/links/apple.svg',
            'themes/default/images/icons/links/baidu_tieba.svg',
            'themes/default/images/icons/links/bandcamp.svg',
            'themes/default/images/icons/links/bitcoin.svg',
            'themes/default/images/icons/links/dailymotion.svg',
            'themes/default/images/icons/links/diaspora.svg',
            'themes/default/images/icons/links/discord.svg',
            'themes/default/images/icons/links/download_as_archive.svg',
            'themes/default/images/icons/links/dropbox.svg',
            'themes/default/images/icons/links/dtube.svg',
            'themes/default/images/icons/links/facebook.svg',
            'themes/default/images/icons/links/favorites.svg',
            'themes/default/images/icons/links/flattr.svg',
            'themes/default/images/icons/links/github.svg',
            'themes/default/images/icons/links/gitlab.svg',
            'themes/default/images/icons/links/google.svg',
            'themes/default/images/icons/links/hacker_news.svg',
            'themes/default/images/icons/links/index.html',
            'themes/default/images/icons/links/instagram.svg',
            'themes/default/images/icons/links/jabber.svg',
            'themes/default/images/icons/links/line.svg',
            'themes/default/images/icons/links/linkedin.svg',
            'themes/default/images/icons/links/mastodon.svg',
            'themes/default/images/icons/links/microsoft.svg',
            'themes/default/images/icons/links/minds.svg',
            'themes/default/images/icons/links/patreon.svg',
            'themes/default/images/icons/links/paypal.svg',
            'themes/default/images/icons/links/pinterest.svg',
            'themes/default/images/icons/links/playstation_network.svg',
            'themes/default/images/icons/links/print.svg',
            'themes/default/images/icons/links/quora.svg',
            'themes/default/images/icons/links/qzone.svg',
            'themes/default/images/icons/links/reddit.svg',
            'themes/default/images/icons/links/rss.svg',
            'themes/default/images/icons/links/sina_weibo.svg',
            'themes/default/images/icons/links/skype.svg',
            'themes/default/images/icons/links/slashdot.svg',
            'themes/default/images/icons/links/snapchat.svg',
            'themes/default/images/icons/links/soundcloud.svg',
            'themes/default/images/icons/links/spotify.svg',
            'themes/default/images/icons/links/stack_overflow.svg',
            'themes/default/images/icons/links/stackexchange.svg',
            'themes/default/images/icons/links/steam.svg',
            'themes/default/images/icons/links/steemit.svg',
            'themes/default/images/icons/links/telegram.svg',
            'themes/default/images/icons/links/tiktok.svg',
            'themes/default/images/icons/links/tumblr.svg',
            'themes/default/images/icons/links/twitch.svg',
            'themes/default/images/icons/links/twitter.svg',
            'themes/default/images/icons/links/utopian.svg',
            'themes/default/images/icons/links/viber.svg',
            'themes/default/images/icons/links/vimeo.svg',
            'themes/default/images/icons/links/vkontakte.svg',
            'themes/default/images/icons/links/wechat.svg',
            'themes/default/images/icons/links/whatsapp.svg',
            'themes/default/images/icons/links/xbox_live.svg',
            'themes/default/images/icons/links/yahoo.svg',
            'themes/default/images/icons/links/youtube.svg',
            'themes/default/images/icons/media_set/lightbox_close.svg',
            'themes/default/images/icons/menu/adminzone/adminzone.svg',
            'themes/default/images/icons/menu/adminzone/audit.svg',
            'themes/default/images/icons/menu/adminzone/audit/email_log.svg',
            'themes/default/images/icons/menu/adminzone/audit/index.html',
            'themes/default/images/icons/menu/adminzone/home.svg',
            'themes/default/images/icons/menu/adminzone/index.html',
            'themes/default/images/icons/menu/adminzone/security.svg',
            'themes/default/images/icons/menu/adminzone/security/index.html',
            'themes/default/images/icons/menu/adminzone/setup.svg',
            'themes/default/images/icons/menu/adminzone/setup/config/base_config.svg',
            'themes/default/images/icons/menu/adminzone/setup/config/index.html',
            'themes/default/images/icons/menu/adminzone/setup/index.html',
            'themes/default/images/icons/menu/adminzone/sponsors.svg',
            'themes/default/images/icons/menu/adminzone/structure.svg',
            'themes/default/images/icons/menu/adminzone/structure/index.html',
            'themes/default/images/icons/menu/adminzone/structure/sitemap/index.html',
            'themes/default/images/icons/menu/adminzone/structure/zones/index.html',
            'themes/default/images/icons/menu/adminzone/structure/zones/zones.svg',
            'themes/default/images/icons/menu/adminzone/style.svg',
            'themes/default/images/icons/menu/adminzone/style/index.html',
            'themes/default/images/icons/menu/adminzone/style/themes/index.html',
            'themes/default/images/icons/menu/adminzone/tools.svg',
            'themes/default/images/icons/menu/adminzone/tools/bulk_content_actions/index.html',
            'themes/default/images/icons/menu/adminzone/tools/index.html',
            'themes/default/images/icons/menu/adminzone/tools/users/index.html',
            'themes/default/images/icons/menu/cms/cms.svg',
            'themes/default/images/icons/menu/cms/index.html',
            'themes/default/images/icons/menu/home.svg',
            'themes/default/images/icons/menu/index.html',
            'themes/default/images/icons/menu/pages.svg',
            'themes/default/images/icons/menu/pages/about_us.svg',
            'themes/default/images/icons/menu/pages/index.html',
            'themes/default/images/icons/menu/pages/keymap.svg',
            'themes/default/images/icons/menu/pages/rules.svg',
            'themes/default/images/icons/menu/rich_content.svg',
            'themes/default/images/icons/menu/rich_content/atoz.svg',
            'themes/default/images/icons/menu/rich_content/index.html',
            'themes/default/images/icons/menu/site_meta.svg',
            'themes/default/images/icons/menu/site_meta/index.html',
            'themes/default/images/icons/menu/site_meta/user_actions/concede.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/index.html',
            'themes/default/images/icons/menu/site_meta/user_actions/invisible.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/join.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/login.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/logout.svg',
            'themes/default/images/icons/menu/social.svg',
            'themes/default/images/icons/menu/social/index.html',
            'themes/default/images/icons/menu/social/members.svg',
            'themes/default/images/icons/menu/social/users_online.svg',
            'themes/default/images/icons/menu/welcome.svg',
            'themes/default/images/icons/no_image.svg',
            'themes/default/images/icons/spare/1.svg',
            'themes/default/images/icons/spare/2.svg',
            'themes/default/images/icons/spare/3.svg',
            'themes/default/images/icons/spare/4.svg',
            'themes/default/images/icons/spare/5.svg',
            'themes/default/images/icons/spare/6.svg',
            'themes/default/images/icons/spare/7.svg',
            'themes/default/images/icons/spare/8.svg',
            'themes/default/images/icons/spare/fun_and_games.svg',
            'themes/default/images/icons/spare/index.html',
            'themes/default/images/icons/spare/introduction.svg',
            'themes/default/images/icons/status/index.html',
            'themes/default/images/icons/tabs/index.html',
            'themes/default/images/icons/tool_buttons/index.html',
            'themes/default/images/icons/tool_buttons/sitemap.svg',
            'themes/default/images/icons/tool_buttons/software_chat.svg',
            'themes/default/images/icons/tool_buttons/top.svg',
            'themes/default/images/icons/tool_buttons/version_desktop.svg',
            'themes/default/images/icons/tool_buttons/version_mobile.svg',
            'themes/default/images/icons/trays/contract.svg',
            'themes/default/images/icons/trays/expand.svg',
            'themes/default/images/icons/trays/expcon.svg',
            'themes/default/images/icons/trays/index.html',
            'themes/default/images/icons_monochrome/admin/add.svg',
            'themes/default/images/icons_monochrome/admin/add_one_category.svg',
            'themes/default/images/icons_monochrome/admin/add_to_category.svg',
            'themes/default/images/icons_monochrome/admin/back.svg',
            'themes/default/images/icons_monochrome/admin/delete.svg',
            'themes/default/images/icons_monochrome/admin/delete2.svg',
            'themes/default/images/icons_monochrome/admin/delete3.svg',
            'themes/default/images/icons_monochrome/admin/edit.svg',
            'themes/default/images/icons_monochrome/admin/edit2.svg',
            'themes/default/images/icons_monochrome/admin/edit_one_category.svg',
            'themes/default/images/icons_monochrome/admin/edit_this.svg',
            'themes/default/images/icons_monochrome/admin/edit_this_category.svg',
            'themes/default/images/icons_monochrome/admin/export.svg',
            'themes/default/images/icons_monochrome/admin/export_spreadsheet.svg',
            'themes/default/images/icons_monochrome/admin/import.svg',
            'themes/default/images/icons_monochrome/admin/import_spreadsheet.svg',
            'themes/default/images/icons_monochrome/admin/index.html',
            'themes/default/images/icons_monochrome/admin/merge.svg',
            'themes/default/images/icons_monochrome/admin/move.svg',
            'themes/default/images/icons_monochrome/admin/remove.svg',
            'themes/default/images/icons_monochrome/admin/sync.svg',
            'themes/default/images/icons_monochrome/admin/tool.svg',
            'themes/default/images/icons_monochrome/admin/tools.svg',
            'themes/default/images/icons_monochrome/admin/view_archive.svg',
            'themes/default/images/icons_monochrome/admin/view_this.svg',
            'themes/default/images/icons_monochrome/admin/view_this_category.svg',
            'themes/default/images/icons_monochrome/admin/xml.svg',
            'themes/default/images/icons_monochrome/arrow_box/arrow_box.svg',
            'themes/default/images/icons_monochrome/arrow_box/arrow_box_hover.svg',
            'themes/default/images/icons_monochrome/arrow_box/index.html',
            'themes/default/images/icons_monochrome/breadcrumbs.svg',
            'themes/default/images/icons_monochrome/buttons/advanced.svg',
            'themes/default/images/icons_monochrome/buttons/all.svg',
            'themes/default/images/icons_monochrome/buttons/all2.svg',
            'themes/default/images/icons_monochrome/buttons/back.svg',
            'themes/default/images/icons_monochrome/buttons/calculate.svg',
            'themes/default/images/icons_monochrome/buttons/cancel.svg',
            'themes/default/images/icons_monochrome/buttons/cancel2.svg',
            'themes/default/images/icons_monochrome/buttons/choose.svg',
            'themes/default/images/icons_monochrome/buttons/clear.svg',
            'themes/default/images/icons_monochrome/buttons/close.svg',
            'themes/default/images/icons_monochrome/buttons/closed.svg',
            'themes/default/images/icons_monochrome/buttons/convert.svg',
            'themes/default/images/icons_monochrome/buttons/copy.svg',
            'themes/default/images/icons_monochrome/buttons/download.svg',
            'themes/default/images/icons_monochrome/buttons/filter.svg',
            'themes/default/images/icons_monochrome/buttons/full_size.svg',
            'themes/default/images/icons_monochrome/buttons/index.html',
            'themes/default/images/icons_monochrome/buttons/more.svg',
            'themes/default/images/icons_monochrome/buttons/new_comment.svg',
            'themes/default/images/icons_monochrome/buttons/new_post_full.svg',
            'themes/default/images/icons_monochrome/buttons/new_reply.svg',
            'themes/default/images/icons_monochrome/buttons/next.svg',
            'themes/default/images/icons_monochrome/buttons/next_none.svg',
            'themes/default/images/icons_monochrome/buttons/no.svg',
            'themes/default/images/icons_monochrome/buttons/pause.svg',
            'themes/default/images/icons_monochrome/buttons/preview.svg',
            'themes/default/images/icons_monochrome/buttons/previous.svg',
            'themes/default/images/icons_monochrome/buttons/previous_none.svg',
            'themes/default/images/icons_monochrome/buttons/proceed.svg',
            'themes/default/images/icons_monochrome/buttons/proceed2.svg',
            'themes/default/images/icons_monochrome/buttons/redirect.svg',
            'themes/default/images/icons_monochrome/buttons/report.svg',
            'themes/default/images/icons_monochrome/buttons/save.svg',
            'themes/default/images/icons_monochrome/buttons/search.svg',
            'themes/default/images/icons_monochrome/buttons/send.svg',
            'themes/default/images/icons_monochrome/buttons/settings.svg',
            'themes/default/images/icons_monochrome/buttons/shrink_size.svg',
            'themes/default/images/icons_monochrome/buttons/simple.svg',
            'themes/default/images/icons_monochrome/buttons/skip.svg',
            'themes/default/images/icons_monochrome/buttons/sort.svg',
            'themes/default/images/icons_monochrome/buttons/thumbnail.svg',
            'themes/default/images/icons_monochrome/buttons/undo.svg',
            'themes/default/images/icons_monochrome/buttons/upload.svg',
            'themes/default/images/icons_monochrome/buttons/yes.svg',
            'themes/default/images/icons_monochrome/content_types/audio.svg',
            'themes/default/images/icons_monochrome/content_types/image.svg',
            'themes/default/images/icons_monochrome/content_types/index.html',
            'themes/default/images/icons_monochrome/content_types/member.svg',
            'themes/default/images/icons_monochrome/content_types/multimedia.svg',
            'themes/default/images/icons_monochrome/content_types/page.svg',
            'themes/default/images/icons_monochrome/content_types/post.svg',
            'themes/default/images/icons_monochrome/content_types/topic.svg',
            'themes/default/images/icons_monochrome/content_types/video.svg',
            'themes/default/images/icons_monochrome/editor/comcode.svg',
            'themes/default/images/icons_monochrome/features.svg',
            'themes/default/images/icons_monochrome/feedback/index.html',
            'themes/default/images/icons_monochrome/feedback/rating.svg',
            'themes/default/images/icons_monochrome/file_types/email_link.svg',
            'themes/default/images/icons_monochrome/file_types/external_link.svg',
            'themes/default/images/icons_monochrome/file_types/index.html',
            'themes/default/images/icons_monochrome/file_types/page_archive.svg',
            'themes/default/images/icons_monochrome/file_types/page_css.svg',
            'themes/default/images/icons_monochrome/file_types/page_doc.svg',
            'themes/default/images/icons_monochrome/file_types/page_feed.svg',
            'themes/default/images/icons_monochrome/file_types/page_js.svg',
            'themes/default/images/icons_monochrome/file_types/page_media.svg',
            'themes/default/images/icons_monochrome/file_types/page_odp.svg',
            'themes/default/images/icons_monochrome/file_types/page_ods.svg',
            'themes/default/images/icons_monochrome/file_types/page_odt.svg',
            'themes/default/images/icons_monochrome/file_types/page_pdf.svg',
            'themes/default/images/icons_monochrome/file_types/page_ppt.svg',
            'themes/default/images/icons_monochrome/file_types/page_torrent.svg',
            'themes/default/images/icons_monochrome/file_types/page_tpl.svg',
            'themes/default/images/icons_monochrome/file_types/page_txt.svg',
            'themes/default/images/icons_monochrome/file_types/page_xls.svg',
            'themes/default/images/icons_monochrome/file_types/page_xml.svg',
            'themes/default/images/icons_monochrome/help.svg',
            'themes/default/images/icons_monochrome/helper_panel/hide.svg',
            'themes/default/images/icons_monochrome/helper_panel/index.html',
            'themes/default/images/icons_monochrome/helper_panel/show.svg',
            'themes/default/images/icons_monochrome/index.html',
            'themes/default/images/icons_monochrome/links/amazon.svg',
            'themes/default/images/icons_monochrome/links/apple.svg',
            'themes/default/images/icons_monochrome/links/baidu_tieba.svg',
            'themes/default/images/icons_monochrome/links/bandcamp.svg',
            'themes/default/images/icons_monochrome/links/bitcoin.svg',
            'themes/default/images/icons_monochrome/links/dailymotion.svg',
            'themes/default/images/icons_monochrome/links/diaspora.svg',
            'themes/default/images/icons_monochrome/links/discord.svg',
            'themes/default/images/icons_monochrome/links/download_as_archive.svg',
            'themes/default/images/icons_monochrome/links/dropbox.svg',
            'themes/default/images/icons_monochrome/links/dtube.svg',
            'themes/default/images/icons_monochrome/links/facebook.svg',
            'themes/default/images/icons_monochrome/links/favorites.svg',
            'themes/default/images/icons_monochrome/links/flattr.svg',
            'themes/default/images/icons_monochrome/links/github.svg',
            'themes/default/images/icons_monochrome/links/gitlab.svg',
            'themes/default/images/icons_monochrome/links/google.svg',
            'themes/default/images/icons_monochrome/links/hacker_news.svg',
            'themes/default/images/icons_monochrome/links/index.html',
            'themes/default/images/icons_monochrome/links/instagram.svg',
            'themes/default/images/icons_monochrome/links/jabber.svg',
            'themes/default/images/icons_monochrome/links/line.svg',
            'themes/default/images/icons_monochrome/links/linkedin.svg',
            'themes/default/images/icons_monochrome/links/mastodon.svg',
            'themes/default/images/icons_monochrome/links/microsoft.svg',
            'themes/default/images/icons_monochrome/links/minds.svg',
            'themes/default/images/icons_monochrome/links/patreon.svg',
            'themes/default/images/icons_monochrome/links/paypal.svg',
            'themes/default/images/icons_monochrome/links/pinterest.svg',
            'themes/default/images/icons_monochrome/links/playstation_network.svg',
            'themes/default/images/icons_monochrome/links/print.svg',
            'themes/default/images/icons_monochrome/links/quora.svg',
            'themes/default/images/icons_monochrome/links/qzone.svg',
            'themes/default/images/icons_monochrome/links/reddit.svg',
            'themes/default/images/icons_monochrome/links/rss.svg',
            'themes/default/images/icons_monochrome/links/sina_weibo.svg',
            'themes/default/images/icons_monochrome/links/skype.svg',
            'themes/default/images/icons_monochrome/links/slashdot.svg',
            'themes/default/images/icons_monochrome/links/snapchat.svg',
            'themes/default/images/icons_monochrome/links/soundcloud.svg',
            'themes/default/images/icons_monochrome/links/spotify.svg',
            'themes/default/images/icons_monochrome/links/stack_overflow.svg',
            'themes/default/images/icons_monochrome/links/stackexchange.svg',
            'themes/default/images/icons_monochrome/links/steam.svg',
            'themes/default/images/icons_monochrome/links/steemit.svg',
            'themes/default/images/icons_monochrome/links/telegram.svg',
            'themes/default/images/icons_monochrome/links/tiktok.svg',
            'themes/default/images/icons_monochrome/links/tumblr.svg',
            'themes/default/images/icons_monochrome/links/twitch.svg',
            'themes/default/images/icons_monochrome/links/twitter.svg',
            'themes/default/images/icons_monochrome/links/utopian.svg',
            'themes/default/images/icons_monochrome/links/viber.svg',
            'themes/default/images/icons_monochrome/links/vimeo.svg',
            'themes/default/images/icons_monochrome/links/vkontakte.svg',
            'themes/default/images/icons_monochrome/links/wechat.svg',
            'themes/default/images/icons_monochrome/links/whatsapp.svg',
            'themes/default/images/icons_monochrome/links/xbox_live.svg',
            'themes/default/images/icons_monochrome/links/yahoo.svg',
            'themes/default/images/icons_monochrome/links/youtube.svg',
            'themes/default/images/icons_monochrome/media_set/lightbox_close.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/adminzone.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/email_log.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/home.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/security.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/setup.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/config/base_config.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/config/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/sponsors.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/sitemap/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/zones/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/zones/zones.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/bulk_content_actions/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/index.html',
            'themes/default/images/icons_monochrome/menu/cms/cms.svg',
            'themes/default/images/icons_monochrome/menu/cms/index.html',
            'themes/default/images/icons_monochrome/menu/home.svg',
            'themes/default/images/icons_monochrome/menu/index.html',
            'themes/default/images/icons_monochrome/menu/pages.svg',
            'themes/default/images/icons_monochrome/menu/pages/about_us.svg',
            'themes/default/images/icons_monochrome/menu/pages/index.html',
            'themes/default/images/icons_monochrome/menu/pages/keymap.svg',
            'themes/default/images/icons_monochrome/menu/pages/rules.svg',
            'themes/default/images/icons_monochrome/menu/rich_content.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/atoz.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/index.html',
            'themes/default/images/icons_monochrome/menu/site_meta.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/index.html',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/concede.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/index.html',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/invisible.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/join.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/login.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/logout.svg',
            'themes/default/images/icons_monochrome/menu/social.svg',
            'themes/default/images/icons_monochrome/menu/social/index.html',
            'themes/default/images/icons_monochrome/menu/social/members.svg',
            'themes/default/images/icons_monochrome/menu/social/users_online.svg',
            'themes/default/images/icons_monochrome/menu/welcome.svg',
            'themes/default/images/icons_monochrome/no_image.svg',
            'themes/default/images/icons_monochrome/spare/1.svg',
            'themes/default/images/icons_monochrome/spare/2.svg',
            'themes/default/images/icons_monochrome/spare/3.svg',
            'themes/default/images/icons_monochrome/spare/4.svg',
            'themes/default/images/icons_monochrome/spare/5.svg',
            'themes/default/images/icons_monochrome/spare/6.svg',
            'themes/default/images/icons_monochrome/spare/7.svg',
            'themes/default/images/icons_monochrome/spare/8.svg',
            'themes/default/images/icons_monochrome/spare/fun_and_games.svg',
            'themes/default/images/icons_monochrome/spare/index.html',
            'themes/default/images/icons_monochrome/spare/introduction.svg',
            'themes/default/images/icons_monochrome/status/index.html',
            'themes/default/images/icons_monochrome/tabs/index.html',
            'themes/default/images/icons_monochrome/tool_buttons/index.html',
            'themes/default/images/icons_monochrome/tool_buttons/sitemap.svg',
            'themes/default/images/icons_monochrome/tool_buttons/software_chat.svg',
            'themes/default/images/icons_monochrome/tool_buttons/top.svg',
            'themes/default/images/icons_monochrome/tool_buttons/version_desktop.svg',
            'themes/default/images/icons_monochrome/tool_buttons/version_mobile.svg',
            'themes/default/images/icons_monochrome/trays/contract.svg',
            'themes/default/images/icons_monochrome/trays/expand.svg',
            'themes/default/images/icons_monochrome/trays/expcon.svg',
            'themes/default/images/icons_monochrome/trays/index.html',
            'themes/default/images/icons_monochrome_sprite.svg',
            'themes/default/images/icons_sprite.svg',
            'themes/default/images/index.html',
            'themes/default/images/iphone.png',
            'themes/default/images/led/index.html',
            'themes/default/images/led/off.svg',
            'themes/default/images/led/on.svg',
            'themes/default/images/loading.gif',
            'themes/default/images/loading.gif.png',
            'themes/default/images/logo/-logo.png',
            'themes/default/images/logo/small_logo.png',
            'themes/default/images/logo/small_white_logo.png',
            'themes/default/images/logo/standalone_logo.png',
            'themes/default/images/na.svg',
            'themes/default/images/no_image.png',
            'themes/default/images/product_logo.png',
            'themes/default/images/results/index.html',
            'themes/default/images/results/sortablefield_asc.svg',
            'themes/default/images/results/sortablefield_asc_nonselected.svg',
            'themes/default/images/results/sortablefield_desc.svg',
            'themes/default/images/results/sortablefield_desc_nonselected.svg',
            'themes/default/images/skitter/index.html',
            'themes/default/images/skitter/sprite-clean.png',
            'themes/default/images/skitter/sprite-default.png',
            'themes/default/images/skitter/sprite-minimalist.png',
            'themes/default/images/skitter/sprite-round.png',
            'themes/default/images/skitter/sprite-square.png',
            'themes/default/images/webclipicon.ico',
            'themes/default/images_custom/.htaccess',
            'themes/default/images_custom/icons/index.html',
            'themes/default/images_custom/icons_monochrome/index.html',
            'themes/default/images_custom/index.html',
            'themes/default/index.html',
            'themes/default/javascript/.htaccess',
            'themes/default/javascript/_cms.js',
            'themes/default/javascript/_cms_behaviors.js',
            'themes/default/javascript/_cms_form.js',
            'themes/default/javascript/_cms_templates.js',
            'themes/default/javascript/_cms_ui.js',
            'themes/default/javascript/_cms_views.js',
            'themes/default/javascript/_dom.js',
            'themes/default/javascript/_json5.js',
            'themes/default/javascript/_polyfill_fetch.js',
            'themes/default/javascript/_polyfill_general.js',
            'themes/default/javascript/_polyfill_keyboardevent_key.js',
            'themes/default/javascript/_polyfill_url.js',
            'themes/default/javascript/_polyfill_web_animations.js',
            'themes/default/javascript/_util.js',
            'themes/default/javascript/cookie_consent.js',
            'themes/default/javascript/global.js',
            'themes/default/javascript/image_slider.js',
            'themes/default/javascript/index.html',
            'themes/default/javascript/installer.js',
            'themes/default/javascript/jquery.js',
            'themes/default/javascript/jsdoc-conf.json',
            'themes/default/javascript/modernizr.js',
            'themes/default/javascript/password_checks.js',
            'themes/default/javascript/plupload.js',
            'themes/default/javascript/skitter.js',
            'themes/default/javascript/sound.js',
            'themes/default/javascript/toastify.js',
            'themes/default/javascript/tree_list.js',
            'themes/default/javascript/webfontloader.js',
            'themes/default/javascript/xsl_mopup.js',
            'themes/default/javascript_custom/.htaccess',
            'themes/default/javascript_custom/index.html',
            'themes/default/templates/.htaccess',
            'themes/default/templates/ACTIONLOGS_SCREEN.tpl',
            'themes/default/templates/ACTIONLOGS_TOGGLE_LINK.tpl',
            'themes/default/templates/BLOCK_MAIN_COMCODE_PAGE_CHILDREN.tpl',
            'themes/default/templates/BLOCK_MAIN_CONTENT.tpl',
            'themes/default/templates/BLOCK_MAIN_CONTENT_FILTERING.tpl',
            'themes/default/templates/BLOCK_MAIN_EMOTICON_CODES.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_BOXES.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_CAROUSEL.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_GRID.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_LIST.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_MOSAIC.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_SLIDER.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_TABLE.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT_TILES.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT__FOOTER.tpl',
            'themes/default/templates/BLOCK_MAIN_MULTI_CONTENT__HEADER.tpl',
            'themes/default/templates/BLOCK_NO_ENTRIES.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_LINE.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_LINE_COMPLEX.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_LINK.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_LINK_2.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_LOGOUT.tpl',
            'themes/default/templates/BLOCK_SIDE_PERSONAL_STATS_NO.tpl',
            'themes/default/templates/BLOCK_TOP_LOGIN.tpl',
            'themes/default/templates/BLOCK_TOP_PERSONAL_STATS.tpl',
            'themes/default/templates/CONTRIBUTORS_SCREEN.tpl',
            'themes/default/templates/EMAIL_LOG_SCREEN.tpl',
            'themes/default/templates/FORUMS_EMBED.tpl',
            'themes/default/templates/FORUM_ATTACHMENT_IMAGE.tpl',
            'themes/default/templates/FORUM_ATTACHMENT_IMAGE_THUMB.tpl',
            'themes/default/templates/FORUM_ATTACHMENT_LINK.tpl',
            'themes/default/templates/GROUP_MEMBER_TIMEOUT_MANAGE_SCREEN.tpl',
            'themes/default/templates/HELP_ICON_PHRASE.tpl',
            'themes/default/templates/IP_BAN_SCREEN.tpl',
            'themes/default/templates/JS_BLOCK.tpl',
            'themes/default/templates/LOGIN_SCREEN.tpl',
            'themes/default/templates/LOOKUP_IP_LIST_ENTRY.tpl',
            'themes/default/templates/LOOKUP_IP_LIST_GROUP.tpl',
            'themes/default/templates/LOOKUP_SCREEN.tpl',
            'themes/default/templates/MASS_SELECT_DELETE_FORM.tpl',
            'themes/default/templates/MASS_SELECT_FORM_BUTTONS.tpl',
            'themes/default/templates/MASS_SELECT_MARKER.tpl',
            'themes/default/templates/PARAM_INFO.tpl',
            'themes/default/templates/QUERY_LOG.tpl',
            'themes/default/templates/QUERY_SCREEN.tpl',
            'themes/default/templates/REDIRECT_POST_METHOD_SCREEN.tpl',
            'themes/default/templates/RED_ALERT.tpl',
            'themes/default/templates/TRANSLATION_LINKS.tpl',
            'themes/default/templates/UPLOAD_SYNDICATION_SETUP_SCREEN.tpl',
            'themes/default/templates/index.html',
            'themes/default/templates_cached/.htaccess',
            'themes/default/templates_cached/EN/index.html',
            'themes/default/templates_cached/index.html',
            'themes/default/templates_custom/.htaccess',
            'themes/default/templates_custom/index.html',
            'themes/default/text/.htaccess',
            'themes/default/text/NEWSLETTER_DEFAULT_FCOMCODE.txt',
            'themes/default/text/index.html',
            'themes/default/text/tempcode_test.txt',
            'themes/default/text_custom/.htaccess',
            'themes/default/text_custom/index.html',
            'themes/default/theme.ini',
            'themes/default/xml/.htaccess',
            'themes/default/xml/index.html',
            'themes/default/xml_custom/.htaccess',
            'themes/default/xml_custom/index.html',
            'themes/index.html',
            'themes/map.ini',
            'uploads/.htaccess',
            'uploads/auto_thumbs/.htaccess',
            'uploads/auto_thumbs/index.html',
            'uploads/captcha/.htaccess',
            'uploads/captcha/index.html',
            'uploads/incoming/.htaccess',
            'uploads/incoming/index.html',
            'uploads/index.html',
            'uploads/repimages/.htaccess',
            'uploads/repimages/index.html',
            'uploads/website_specific/index.html',
            'web.config',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/ACTIONLOGS_SCREEN.tpl' => 'administrative__actionlogs_screen',
            'templates/ACTIONLOGS_TOGGLE_LINK.tpl' => 'administrative__actionlogs_toggle_link',
            'templates/LOGIN_SCREEN.tpl' => 'login_screen',
            'templates/REDIRECT_POST_METHOD_SCREEN.tpl' => 'redirect_post_method_screen',
            'templates/FORUMS_EMBED.tpl' => 'forums_embed',
            'templates/JS_BLOCK.tpl' => 'js_block',
            'templates/PARAM_INFO.tpl' => 'param_info',
            'templates/BLOCK_SIDE_PERSONAL_STATS.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_LINE.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_LINK_2.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_LINK.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_LINE_COMPLEX.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_LOGOUT.tpl' => 'block_side_personal_stats',
            'templates/BLOCK_SIDE_PERSONAL_STATS_NO.tpl' => 'block_side_personal_stats_no',
            'templates/BLOCK_TOP_LOGIN.tpl' => 'block_top_login',
            'templates/BLOCK_TOP_PERSONAL_STATS.tpl' => 'block_top_personal_stats',
            'templates/BLOCK_NO_ENTRIES.tpl' => 'nothing_here',
            'templates/BLOCK_MAIN_EMOTICON_CODES.tpl' => 'block_main_emoticon_codes',
            'templates/BLOCK_MAIN_COMCODE_PAGE_CHILDREN.tpl' => 'block_main_comcode_page_children',
            'templates/QUERY_LOG.tpl' => 'administrative__query_screen',
            'templates/QUERY_SCREEN.tpl' => 'administrative__query_screen',
            'templates/FORUM_ATTACHMENT_IMAGE.tpl' => 'forum_attachment_image',
            'templates/FORUM_ATTACHMENT_IMAGE_THUMB.tpl' => 'forum_attachment_link',
            'templates/FORUM_ATTACHMENT_LINK.tpl' => 'forum_attachment_link',
            'text/tempcode_test.txt' => 'administrative__tempcode_test',
            'templates/EMAIL_LOG_SCREEN.tpl' => 'email_log_screen',
            'templates/BLOCK_MAIN_CONTENT_FILTERING.tpl' => 'block_main_content_filtering',
            'templates/BLOCK_MAIN_CONTENT.tpl' => 'block_main_content',
            'templates/BLOCK_MAIN_MULTI_CONTENT_BOXES.tpl' => 'block_main_multi_content_boxes',
            'templates/BLOCK_MAIN_MULTI_CONTENT_CAROUSEL.tpl' => 'block_main_multi_content_carousel',
            'templates/BLOCK_MAIN_MULTI_CONTENT_GRID.tpl' => 'block_main_multi_content_grid',
            'templates/BLOCK_MAIN_MULTI_CONTENT_LIST.tpl' => 'block_main_multi_content_list',
            'templates/BLOCK_MAIN_MULTI_CONTENT_MOSAIC.tpl' => 'block_main_multi_content_mosaic',
            'templates/BLOCK_MAIN_MULTI_CONTENT_SLIDER.tpl' => 'block_main_multi_content_slider',
            'templates/BLOCK_MAIN_MULTI_CONTENT_TABLE.tpl' => 'block_main_multi_content_table',
            'templates/BLOCK_MAIN_MULTI_CONTENT_TILES.tpl' => 'block_main_multi_content_tiles',
            'templates/BLOCK_MAIN_MULTI_CONTENT__HEADER.tpl' => 'block_main_multi_content_boxes',
            'templates/BLOCK_MAIN_MULTI_CONTENT__FOOTER.tpl' => 'block_main_multi_content_boxes',
            'templates/MASS_SELECT_FORM_BUTTONS.tpl' => 'mass_select_form_buttons',
            'templates/UPLOAD_SYNDICATION_SETUP_SCREEN.tpl' => 'upload_syndication_setup_screen',
            'templates/GROUP_MEMBER_TIMEOUT_MANAGE_SCREEN.tpl' => 'group_member_timeout_manage_screen',
            'templates/CONTRIBUTORS_SCREEN.tpl' => 'contributors_screen',
            'templates/TRANSLATION_LINKS.tpl' => 'translation_links',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_content() : object
    {
        return lorem_globalise(do_lorem_template('BLOCK_MAIN_CONTENT', [
            'BLOCK_ID' => lorem_word(),
            'TYPE' => lorem_word(),
            'TITLE' => lorem_phrase(),
            'RAW_DATE' => placeholder_date_raw(),
            'DATE' => placeholder_date(),
            'CONTENT' => lorem_phrase_html(),
            'ADD_NAME' => lorem_phrase(),
            'SUBMIT_URL' => placeholder_url(),
            'ARCHIVE_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_boxes() : object
    {
        $map = $this->preview_main_multi_content('boxes');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_BOXES', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_carousel() : object
    {
        $map = $this->preview_main_multi_content('carousel');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_CAROUSEL', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_grid() : object
    {
        $map = $this->preview_main_multi_content('grid');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_GRID', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_list() : object
    {
        $map = $this->preview_main_multi_content('list');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_LIST', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_mosaic() : object
    {
        $map = $this->preview_main_multi_content('mosaic');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_MOSAIC', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_slider() : object
    {
        $map = $this->preview_main_multi_content('slider');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_SLIDER', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_table() : object
    {
        $map = $this->preview_main_multi_content('table');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_TABLE', $map), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_multi_content_tiles() : object
    {
        $map = $this->preview_main_multi_content('tiles');

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_MULTI_CONTENT_TILES', $map), null, '', true);
    }

    /**
     * Get a preview of main_multi_content render mode.
     *
     * @param  string $render_mode The render mode
     * @set boxes carousel grid list mosaic slider table tiles
     * @return array Template map array
     */
    public function preview_main_multi_content(string $render_mode) : array
    {
        $keymap = [
            'test' => lorem_phrase(),
        ];

        $content = [];
        switch ($render_mode) {
            case 'boxes':
                $content[] = lorem_phrase_html();
                break;

            case 'carousel':
                $content[] = placeholder_image();
                break;

            case 'grid':
                $content[] = '';
                break;

            case 'list':
                $content[] = placeholder_link();
                break;

            case 'mosaic':
                $content[] = '';
                break;

            case 'slider':
                $content[] = '';
                break;

            case 'table':
                $content = [['KEYMAP' => $keymap]];
                break;

            case 'tiles':
                $content[] = '';
                break;
        }

        $content_data = [
            [
                'CONTENT_TYPE' => lorem_word(),
                'CONTENT_TYPE_LABEL' => lorem_phrase(),
                'CONTENT_TYPE_ICON' => placeholder_image_url(),
                'CONTENT_ID' => placeholder_codename(),
                'CONTENT_URL' => placeholder_url(),
                'CONTENT_TITLE_PLAIN' => lorem_phrase(),
                'CONTENT_TITLE_HTML' => lorem_phrase_html(),
                'CONTENT_DESCRIPTION' => lorem_paragraph_html(),
                'CONTENT_IMAGE_URL' => placeholder_image_url(),
                'CONTENT_USERNAME' => lorem_word(),
                'CONTENT_AUTHOR' => lorem_word(),
                'CONTENT_TIME_LABEL' => lorem_word(),
                'CONTENT_TIME' => placeholder_date(),
                '_CONTENT_TIME' => placeholder_date_raw(),
            ],
        ];

        if ($render_mode != 'table') {
            $content_data[0]['CONTENT_KEYMAP'] = $keymap;
        }

        $shared_keymap_headings = [
            'test' => lorem_phrase(),
        ];

        $map = [
            'BLOCK_ID' => lorem_word(),
            'BLOCK_PARAMS' => '',
            'TYPE' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'CONTENT' => $content,
            'CONTENT_TYPE' => lorem_phrase(),
            'CONTENT_DATA' => $content_data,
            'SUBMIT_URL' => placeholder_url(),
            'ARCHIVE_URL' => placeholder_url(),
            'PAGINATION' => placeholder_pagination(),
            'ADD_STRING' => lorem_phrase(),
            'SHARED_KEYMAP_HEADINGS' => $shared_keymap_headings,

            'START' => '0',
            'MAX' => '10',
            'START_PARAM' => 'x_start',
            'MAX_PARAM' => 'x_max',
            'EXTRA_GET_PARAMS' => '',
        ];

        return $map;
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__email_log_screen() : object
    {
        return lorem_globalise(do_lorem_template('EMAIL_LOG_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'RESULTS_TABLE' => placeholder_table(),
            'MASS_DELETE_URL' => placeholder_url(),
            'MASS_SEND_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__actionlogs_toggle_link() : object
    {
        return lorem_globalise(do_lorem_template('ACTIONLOGS_TOGGLE_LINK', [
            'URL' => placeholder_url(),
            'LONELY' => null,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__actionlogs_screen() : object
    {
        return lorem_globalise(do_lorem_template('ACTIONLOGS_SCREEN', [
            'TABLE' => placeholder_table(),
            'TITLE' => lorem_screen_title(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__login_screen() : object
    {
        $_GET['wide'] = '1';

        return lorem_globalise(do_lorem_template('LOGIN_SCREEN', [
            'EXTRA' => lorem_phrase(),
            'USERNAME' => lorem_word(),
            'JOIN_URL' => placeholder_url(),
            'TITLE' => lorem_screen_title(),
            'LOGIN_URL' => placeholder_url(),
            'PASSION' => '',
            'TARGET' => '_top',
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__redirect_post_method_screen() : object
    {
        return lorem_globalise(do_lorem_template('REDIRECT_POST_METHOD_SCREEN', [
            'REFRESH' => '',
            'TITLE' => lorem_screen_title(),
            'TEXT' => lorem_sentence_html(),
            'URL' => placeholder_url(),
            'POST' => lorem_phrase(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__forums_embed() : object
    {
        return lorem_globalise(do_lorem_template('FORUMS_EMBED', [
            'FORUMS' => build_url(['page' => ''], ''),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__js_block() : object
    {
        return lorem_globalise(do_lorem_template('JS_BLOCK', [
            'BLOCK_PARAMS' => '',
            'SELF_URL' => get_self_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__param_info() : object
    {
        $parameters = [
            'A' => 'a',
            'B' => 'b',
        ];

        return lorem_globalise(do_lorem_template('PARAM_INFO', [
            'MAP' => $parameters,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_side_personal_stats() : object
    {
        $details = new Tempcode();
        $details->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINE', [
            'KEY' => lorem_word(),
            'VALUE' => placeholder_number(),
            'RAW_VALUE' => placeholder_number(),
        ]));
        $details->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINE_COMPLEX', [
            'KEY' => do_lang_tempcode('USERGROUP'),
            'RAW_VALUE' => placeholder_url(),
            'VALUE' => placeholder_link(),
        ]));

        $links = new Tempcode();
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK_2', [
            'NAME' => lorem_word_2(),
            'DESCRIPTION' => lorem_phrase(),
            'URL' => placeholder_url(),
            'POST' => false,
        ]));
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK', [
            'NAME' => lorem_word(),
            'URL' => placeholder_url(),
            'REL' => 'me',
        ]));
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LOGOUT', [
            'NAME' => do_lang_tempcode('LOGOUT'),
            'URL' => placeholder_url(),
        ]));

        $links_ecommerce = new Tempcode();
        $links_ecommerce->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK_2', [
            'NAME' => lorem_word_2(),
            'DESCRIPTION' => lorem_phrase(),
            'URL' => placeholder_url(),
            'POST' => false,
        ]));

        return lorem_globalise(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS', [
            'BLOCK_ID' => lorem_word(),
            'AVATAR_URL' => placeholder_avatar(),
            'LINKS' => $links,
            'LINKS_ECOMMERCE' => $links_ecommerce,
            'DETAILS' => $details,
            'USERNAME' => lorem_word(),
            'NUM_UNREAD_PTS' => placeholder_number(),
            'MEMBER_ID' => placeholder_numeric_id(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_top_personal_stats() : object
    {
        $details = new Tempcode();
        $details->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINE', [
            'KEY' => lorem_word(),
            'RAW_VALUE' => placeholder_number(),
            'VALUE' => placeholder_number(),
        ]));
        $details->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINE_COMPLEX', [
            'KEY' => do_lang_tempcode('USERGROUP'),
            'RAW_VALUE' => placeholder_url(),
            'VALUE' => placeholder_link(),
        ]));

        $links = new Tempcode();
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK_2', [
            'NAME' => lorem_word_2(),
            'DESCRIPTION' => lorem_phrase(),
            'URL' => placeholder_url(),
            'POST' => false,
        ]));
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK', [
            'NAME' => lorem_word(),
            'URL' => placeholder_url(),
            'REL' => 'me',
        ]));
        $links->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LOGOUT', [
            'NAME' => do_lang_tempcode('LOGOUT'),
            'URL' => placeholder_url(),
        ]));

        $links_ecommerce = new Tempcode();
        $links_ecommerce->attach(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_LINK_2', [
            'NAME' => lorem_word_2(),
            'DESCRIPTION' => lorem_phrase(),
            'URL' => placeholder_url(),
            'POST' => false,
        ]));

        return lorem_globalise(do_lorem_template('BLOCK_TOP_PERSONAL_STATS', [
            'BLOCK_ID' => lorem_word(),
            'AVATAR_URL' => placeholder_avatar(),
            'LINKS' => $links,
            'LINKS_ECOMMERCE' => $links_ecommerce,
            'DETAILS' => $details,
            'USERNAME' => lorem_word(),
            'MEMBER_ID' => placeholder_numeric_id(),
            'NUM_UNREAD_PTS' => placeholder_number(),
        ]), null, '', false);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_side_personal_stats_no() : object
    {
        return lorem_globalise(do_lorem_template('BLOCK_SIDE_PERSONAL_STATS_NO', [
            'BLOCK_ID' => lorem_word(),
            'TITLE' => lorem_phrase(),
            'FULL_LOGIN_URL' => placeholder_url(),
            'JOIN_URL' => placeholder_url(),
            'LOGIN_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_top_login() : object
    {
        return lorem_globalise(do_lorem_template('BLOCK_TOP_LOGIN', [
            'BLOCK_ID' => lorem_word(),
            'TITLE' => lorem_phrase(),
            'FULL_LOGIN_URL' => placeholder_url(),
            'JOIN_URL' => placeholder_url(),
            'LOGIN_URL' => placeholder_url(),
        ]), null, '', false);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__nothing_here() : object
    {
        return lorem_globalise(do_lorem_template('BLOCK_NO_ENTRIES', [
            'BLOCK_ID' => lorem_word(),
            'HIGH' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'MESSAGE' => lorem_phrase(),
            'ADD_NAME' => lorem_word(),
            'SUBMIT_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_emoticon_codes() : object
    {
        require_code('comcode_renderer');

        $_emoticons = placeholder_emoticons();
        $emoticons = [];

        global $EMOTICON_LEVELS;
        foreach ($_emoticons as $code => $imgcode) {
            if (($EMOTICON_LEVELS === null) || ($EMOTICON_LEVELS[$code] < 3)) {
                $emoticons[] = [
                    'CODE' => $code,
                    'TPL' => do_emoticon($imgcode),
                ];
            }
        }

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_EMOTICON_CODES', [
            'BLOCK_ID' => lorem_word(),
            'EMOTICONS' => $emoticons,
            'NUM_COLUMNS' => '4',
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_comcode_page_children() : object
    {
        $children = [];
        foreach (placeholder_array() as $i => $temp) {
            $children[] = [
                'TITLE' => $temp,
                'PAGE' => lorem_word(),
                'ZONE' => lorem_word(),
            ];
        }

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_COMCODE_PAGE_CHILDREN', [
            'BLOCK_ID' => lorem_word(),
            'CHILDREN' => $children,
            'THE_PAGE' => lorem_phrase(),
            'THE_ZONE' => lorem_phrase(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__query_screen() : object
    {
        $queries = new Tempcode();
        foreach (placeholder_array() as $value) {
            $queries->attach(do_lorem_template('QUERY_LOG', [
                'TIME' => placeholder_number(),
                'ROWS' => placeholder_number(),
                'TEXT' => lorem_sentence(),
            ]));
        }

        return lorem_globalise(do_lorem_template('QUERY_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'TOTAL' => lorem_phrase(),
            'TOTAL_TIME' => placeholder_number(),
            'QUERIES' => $queries,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__forum_attachment_image() : object
    {
        return lorem_globalise(do_lorem_template('FORUM_ATTACHMENT_IMAGE', [
            'URL' => placeholder_image_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__forum_attachment_link() : object
    {
        $content = do_lorem_template('FORUM_ATTACHMENT_IMAGE_THUMB', [
            'FULL' => placeholder_url(),
            'URL' => placeholder_image_url(),
        ]);

        $content->attach(do_lorem_template('FORUM_ATTACHMENT_LINK', [
            'FULL' => placeholder_url(),
            'FILENAME' => lorem_word(),
            'CLEAN_SIZE' => placeholder_filesize(),
            '_NUM_DOWNLOADS' => placeholder_number(),
            'NUM_DOWNLOADS' => placeholder_number(),
        ]));

        return lorem_globalise($content, null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__tempcode_test() : object
    {
        return lorem_globalise(do_lorem_template('tempcode_test', [
            'EMPTY1' => '',
            'EMPTY2' => new Tempcode(),
            'NONEMPTY' => lorem_word(),
            'PASSED' => 'This is a passed parameter',
            'SIMPLE_ARRAY' => ['1', '2', '3'],
            'ARRAY' => [
                ['A' => 'A1', 'B' => 'B1', 'C' => 'C1'],
                ['A' => 'A2', 'B' => 'B2', 'C' => 'C2'],
                ['A' => 'A3', 'B' => 'B3', 'C' => 'C3'],
                ['A' => 'A4', 'B' => 'B4', 'C' => 'C4'],
            ],
        ], null, false, null, '.txt', 'text'), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__mass_select_form_buttons() : object
    {
        $buttons = do_lorem_template('MASS_SELECT_FORM_BUTTONS', [
            'TYPE' => placeholder_codename(),
        ]);

        $fields = new Tempcode();
        $fields->attach(do_lorem_template('FORM_SCREEN_INPUT_HUGE', [
            'RAW' => true,
            'SCROLLS' => '',
            'DESCRIPTION_SIDE' => lorem_sentence(),
            'REQUIRED' => '',
            '_REQUIRED' => '',
            'TABINDEX' => placeholder_number(),
            'PRETTY_NAME' => lorem_word(),
            'DESCRIPTION' => lorem_sentence(),
            'NAME' => placeholder_codename(),
            'DEFAULT' => '',
            'ROWS' => '20',
        ]));

        return lorem_globalise(do_lorem_template('FORM', [
            'GET' => false,
            'SKIP_WEBSTANDARDS' => true,
            'HIDDEN' => $buttons,
            'URL' => placeholder_url(),
            'FIELDS' => $fields,
            'SUBMIT_ICON' => 'buttons/proceed',
            'SUBMIT_NAME' => lorem_word(),
            'SUBMIT_BUTTON_CLASS' => null,
            'TEXT' => '',
            'JS_FUNCTION_CALLS' => [],
            'SKIP_REQUIRED' => null,
            'SECONDARY_FORM' => false,
            'TABINDEX' => placeholder_number(),
            'SUPPORT_AUTOSAVE' => false,
            'ANALYTIC_EVENT_CATEGORY' => null,
            'MODSECURITY_WORKAROUND' => null,
            'NO_SIZING' => null,
            'PREVIEW' => null,
            'TITLE' => null,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_content_filtering() : object
    {
        $links = [
            [
                'ACTIVE' => true,
                'TITLE' => lorem_phrase(),
                'URL' => placeholder_url(),
            ],
        ];

        return lorem_globalise(do_lorem_template('BLOCK_MAIN_CONTENT_FILTERING', [
            'BLOCK_ID' => lorem_word(),
            'FIELDS' => placeholder_fields(),
            'ACTIVE_FILTER' => placeholder_codename(),
            'SUBMIT_ICON' => 'buttons/proceed',
            'LINKS' => $links,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__upload_syndication_setup_screen() : object
    {
        return lorem_globalise(do_lorem_template('UPLOAD_SYNDICATION_SETUP_SCREEN', [
            'LABEL' => lorem_phrase(),
            'HOOK' => lorem_word(),
            'NAME' => lorem_word(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__group_member_timeout_manage_screen() : object
    {
        $timeouts = [
            [
                'USERNAME' => lorem_word(),
                'MEMBER_ID' => placeholder_numeric_id(),
                'GROUP_ID' => placeholder_numeric_id(),
                'DATE_INPUT' => lorem_phrase(),
            ],
        ];

        return lorem_globalise(do_lorem_template('GROUP_MEMBER_TIMEOUT_MANAGE_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'TIMEOUTS' => $timeouts,
            'GROUPS' => [placeholder_numeric_id() => lorem_word()],
            'DATE_INPUT' => lorem_phrase(),
            'URL' => placeholder_url(),
            'PAGINATION' => placeholder_pagination(),
            'PING_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__contributors_screen() : object
    {
        $patreon_patrons = [
            [
                'USERNAME' => lorem_word(),
                'NAME' => lorem_word(),
                'MONTHLY' => placeholder_number(),
            ],
        ];
        $contributors = [
            lorem_word() => ['AREAS' => [lorem_word()]],
        ];

        return lorem_globalise(do_lorem_template('CONTRIBUTORS_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'PATREON_PATRONS' => $patreon_patrons,
            'CONTRIBUTORS' => $contributors,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declaritive.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__translation_links() : object
    {
        $alt_langs = [
            [
                'LANG' => 'FR',
                'CONSISTENT_DEFAULT' => false,
            ],
            [
                'LANG' => 'DE',
                'CONSISTENT_DEFAULT' => false,
            ],
        ];

        return do_lorem_template('TRANSLATION_LINKS', [
            'ALT_LANGS' => $alt_langs,
        ]);
    }
}
